<?php

namespace App\Http\Controllers\Api\Properties;

use App\Http\Controllers\Controller;

use Illuminate\Http\Request;

use App\PropertyDetails;

use App\Http\Requests;

use App\Deals;

use Validator;

use Response;

use Config;

use Log;

use DB;

class DealsController extends Controller
{

    public function __construct(){      
       $this->_s3_path               = Config::get('filesystems.s3_path');
    }
    
    public function getOwnerDealsList(Request $request){

    	$owner_id = $request['owner_id'];

    	$data 	= DB::table('deals as d')
    				->leftJoin('property_details as pd', 'pd.property_id', '=', 'd.property_id')
    				->leftJoin('users as u', 'u.id', '=', 'pd.user_id')
    				->select(
                        'd.*',
                        DB::raw('DATE_FORMAT(d.from_date, "%d/%m/%y") as from_date'),
                        DB::raw('DATE_FORMAT(d.to_date, "%d/%m/%y") as to_date'), 
                        'pd.property_title')
    				->where('d.owner_id', $owner_id)
    				//->where('u.status', 'active')
    				->orderBy('d.created_at', 'desc')
    				->get();
    	if($data)
    	{
    		return Response(array('success'=>1, 'message'=>'Deals found', 'data' =>$data), 200);
    	}else{

    		return Response(array('success'=>0, 'message'=>'Deals not found'), 200);
    	}
    }

    public function getDealsById($id){
    	

    	$result = DB::table('deals')->select('*')->where('id', $id)->first();

    	if($result){

    		$response = array('success'=>1, 'message'=>'Deal found successfully!', 'data'=>$result);

    		return response()->json($response);
    	}else{

    		$response = array('success'=>0, 'message'=>'Deal not found, try again!');

    		return response()->json($response);
    	}

    }

    public function deleteDeal(Request $request){

    	$id = $request['id'];

    	$result = DB::table('deals')->where('id', $id)->delete();

    	if($result){

    		$response = array('success'=>1, 'message'=>'Deal deleted successfully!');

    		return response()->json($response);
    	}else{

    		$response = array('success'=>0, 'message'=>'Deal not deleted, try again!');

    		return response()->json($response);
    	}
    }

    public function addDeals(Request $request)
    {
    	
    	$request = $request->all();		
		
		$addRules = array(
						'property_id'       =>'required',
                        'owner_id'          =>'required',
                        'deal_type'         =>'required',
                        'amount'            =>'required|regex:/[0-9]/',
                        'from_date'         =>'date',
                        'to_date'           =>'date|date_custom_validation:from_date,to_date|before_or_equal:from_date',						
					);

        Validator::extend('date_custom_validation', function ($attribute, $value, $parameters, $validator) {
          $inputs = $validator->getData();
            
          $data   = DB::table('deals')
                    ->select('*')  
                    ->whereRaw('to_date >= "'.$inputs['from_date'].'"')
                    ->whereRaw('from_date <= "'.$inputs['to_date'].'"')
                    ->where('property_id', $inputs['property_id'])
                    ->get();

            
          if(count($data)){
            return false;
          } else{
            return true;
          } 
          
        });

        $message = array(
                     'to_date.before_or_equal' => 'From date should not be greater than To date',
                     'date_custom_validation'  => 'Some of the dates has deal already for this property, please try another dates'  
                   );
				
		Validator::extend('before_or_equal', function($attribute, $value, $parameters, $validator) {
            return strtotime($validator->getData()[$parameters[0]]) <= strtotime($value);
        });

        $validator = Validator::make(

			$request, $addRules, $message

		);

		if($validator->fails()){

			return Response::json(array('success'=>0, 'message'=>$validator->getMessageBag()->first()), 200);
		}else{


			$result = $this->saveDealFormValues($request);

			if($result){

				return Response::json(array('success'=>1, 'message'=>'Deal added successfully!'), 200);	
			}else{

				return Response::json(array('success'=>0, 'message'=>'Deal not added successfully!'), 200);
			}
						
		}
    }

    public function updateDeals(Request $request){

    	$request = $request->all();		
		
		$updateRules = array(
                        'property_id'       =>'required',
                        'owner_id'          =>'required',
                        'deal_type'         =>'required',
                        'amount'            =>'required|regex:/[0-9]/',
                        'from_date'         =>'date',
                        'to_date'           =>'date|before_or_equal:from_date|date_custom_validation:deals,from_date,to_date'                       
                    );

        //print_r($updateRules); die();

        Validator::extend('date_custom_validation', function ($attribute, $value, $parameters, $validator) {
          $inputs = $validator->getData();
          
          $deal_array = array('deal_id' => $inputs['deal_id']);  
          $data   = DB::table('deals')
                    ->select('*')  
                    ->whereRaw('to_date >= "'.$inputs['from_date'].'"')
                    ->whereRaw('from_date <= "'.$inputs['to_date'].'"')
                    ->where('property_id', $inputs['property_id'])
                    ->whereRaw('id !='.$inputs['deal_id'])
                    ->get();

            
          if(count($data)){
            return false;
          } else{
            return true;
          } 
          
        });

        $message = array(
                     'to_date.before_or_equal' => 'To date should be greater than From date', 
                     'date_custom_validation'  => 'Some of the dates has deal already for this property, please try another dates'
                   );
                
        Validator::extend('before_or_equal', function($attribute, $value, $parameters, $validator) {
            return strtotime($validator->getData()[$parameters[0]]) <= strtotime($value);
        });
				
		$validator = Validator::make(

			$request, $updateRules, $message

		);


		if($validator->fails()){

			return Response::json(array('success'=>0, 'message'=>$validator->getMessageBag()->first()), 200);
		}else{


			$result = $this->updateDealFormValues($request);

			if($result){

				return Response::json(array('success'=>1, 'message'=>'Deal updated successfully!'), 200);	
			}else{

				return Response::json(array('success'=>0, 'message'=>'Deal not updated successfully!'), 200);
			}
						
		}
    }

    public function updateDealFormValues($input){

    	$dealsObj = \App\Deals::where('id','=',$input['deal_id'])->first();
    	$dealsObj->owner_id 		= $input['owner_id'];
    	$dealsObj->property_id 		= $input['property_id'];
    	$dealsObj->deal_type 		= $input['deal_type'];
    	$dealsObj->amount 			= $input['amount'];
    	$dealsObj->from_date 		= date('Y-m-d',strtotime($input['from_date']));
    	$dealsObj->to_date 			= date('Y-m-d',strtotime($input['to_date']));
    	/*$dealsObj->from_time 		= $input['from_time'];
    	$dealsObj->to_time 			= $input['to_time'];*/
    	$dealsObj->created_at 		= date('Y-m-d h:i:s');
    	$dealsObj->updated_at 		= date('Y-m-d h:i:s');
    	$dealsObj->save();

    	return $dealsObj->id;
    }

    public function saveDealFormValues($input){

    	$dealsObj = new Deals;
    	$dealsObj->owner_id 		= $input['owner_id'];
    	$dealsObj->property_id 		= $input['property_id'];
    	$dealsObj->deal_type 		= $input['deal_type'];
    	$dealsObj->amount 			= $input['amount'];
    	$dealsObj->from_date 		= date('Y-m-d',strtotime($input['from_date']));
    	$dealsObj->to_date 			= date('Y-m-d',strtotime($input['to_date']));
    	/*$dealsObj->from_time 		= $input['from_time'];
    	$dealsObj->to_time 			= $input['to_time'];*/
    	$dealsObj->created_at 		= date('Y-m-d h:i:s');
    	$dealsObj->updated_at 		= date('Y-m-d h:i:s');
    	$dealsObj->save();

    	return $dealsObj->id;
    }

    public function getDealProperties(Request $request){

        $ip_address = $_SERVER['REMOTE_ADDR']; 
        if($ip_address=='::1'){
            $ip = '127.0.0.1';
        }else{
            $ip = $ip_address;
        }


        $data = $this->getLatestDeals($ip);

        if($data){

            return Response::json(array('success'=>1, '_s3_path'=>$this->_s3_path, 'message'=>'Deal found', 'data'=>$data), 200);   
        }else{

            return Response::json(array('success'=>0, 'message'=>'No deals found'), 200);
        }
    }

    public function getFilterDeals(Request $request)
    {   

        $filter_request = $request['filter_type'];

        $ip_address = $_SERVER['REMOTE_ADDR']; 
        
        if($ip_address=='::1'){
            $ip = '127.0.0.1';
        }else{
            $ip = $ip_address;
        }

        $deals_query = DB::table('property_details as pd')
                ->select('pd.*','d.deal_type','amount as deal_amount', 'pg.image_name as image', 'pg.property_gallery_id as pg_id',
                        (DB::raw('(SELECT count(cpd.click_time)+1 FROM property_clicks as cpd  WHERE cpd.click_time >= CURDATE() - INTERVAL 1 DAY AND cpd.property_id=pd.property_id) last_one_day_record')),
                        (DB::raw('(SELECT min(pr.rate_per_week) FROM property_rate as pr WHERE pr.property_id=pd.property_id group by week(CURDATE())) week_rate')),
                        (DB::raw('(SELECT min(pr.rate_per_week) FROM property_rate as pr WHERE pr.property_id=pd.property_id and pr.start_date >= CURDATE() ) min_week_rate')),  
                        (DB::raw('(SELECT count(property_id) FROM user_favourite_properties as fp WHERE fp.property_id=pd.property_id and fp.ip_address="'.$ip.'" group by fp.property_id, fp.ip_address) favourite_property')),

                        (DB::raw('(SELECT id FROM user_favourite_properties as ufp WHERE ufp.property_id=pd.property_id and ufp.ip_address="'.$ip.'" group by ufp.property_id)favourite_id')),
                        (DB::raw('(SELECT CAST(( CAST(sum(t.rating) AS UNSIGNED) / (count(t.rating)*5))* 100 AS UNSIGNED) FROM testimonials as t WHERE t.property_id=pd.property_id and t.status="publish" and t.admin_status="active") testimonial_rating')),
                        (DB::raw("(SELECT (CASE 
                            WHEN DATEDIFF(UTC_TIMESTAMP, cpd.property_view_time) != 0 THEN 
                                CASE 
                                    WHEN DATEDIFF(UTC_TIMESTAMP, cpd.property_view_time) > 1 THEN CONCAT(DATEDIFF(UTC_TIMESTAMP, cpd.property_view_time) ,' days ago') ELSE CONCAT(DATEDIFF(UTC_TIMESTAMP, cpd.property_view_time) ,' day ago') END
                            WHEN HOUR(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) != 0 THEN 
                                CASE
                                    WHEN HOUR(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) > 1 THEN CONCAT(HOUR(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) ,' hours ago') ELSE CONCAT(HOUR(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) ,' hour ago') END
                            WHEN MINUTE(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) != 0 THEN 
                                CASE
                                    WHEN MINUTE(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) > 1 THEN CONCAT(MINUTE(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) ,' minutes ago') ELSE CONCAT(MINUTE(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) ,' minute ago') END
                            ELSE
                                CASE
                                    WHEN SECOND(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) > 1 THEN CONCAT(SECOND(TIMEDIFF(UTC_TIMESTAMP, pd.property_view_time)) ,' seconds ago') ELSE 'now' END
                        END ) from property_details as cpd where cpd.property_id = pd.property_id) time_since"))
                )
                ->leftJoin('property_gallery as pg', 'pg.property_id','=','pd.property_id')
                ->leftJoin('deals as d', 'd.property_id', '=', 'pd.property_id')
                ->leftJoin('users as u', 'u.id', '=', 'pd.user_id')
                ->groupBy('pd.property_id')         
                ->whereRaw('pd.property_id = d.property_id')
                ->whereRaw('d.to_date >= CURDATE()')
                ->where("pd.verified", 'yes')
                ->where("pd.status", 'active')
                ->where('u.status', 'active');
                
                if($filter_request=='latest'){

                    $deals_query->orderBy('d.created_at', 'desc');

                }else if($filter_request=='most_viewed'){
                    
                    $deals_query->orderBy(DB::raw("MAX(d.deal_clicks)"), 'desc');  

                }else if($filter_request=='best_deals'){
                    
                    $deals_query->orderBy(DB::raw("(CASE 
                                                WHEN d.deal_type='percentage' THEN d.amount*pd.standard_rate_per_week/100 
                                                WHEN d.deal_type='flat' THEN d.amount                     
                                            END)"), 'asc');
                }
                /*$deals_query->orderBy(DB::raw("(CASE 
                        WHEN d.deal_type='percentage' THEN d.amount*pd.standard_rate_per_week/100 
                        WHEN d.deal_type='flat' THEN d.amount                     
                    END)"), 'asc'); */               
                $deals_query->groupBy('d.property_id');
                $deals_query->offset(0)->limit(9);
                
                $data = $deals_query->get();

        if($data){

            return Response::json(array('success'=>1, 'message'=>'Deal found', 'data'=>$data), 200);   
        }else{

            return Response::json(array('success'=>0, 'message'=>'No deals found'), 200);
        }
        
    } 

    public function getLatestDeals($ip){        


        $data = DB::table('property_details as pd')
                ->select(
                        'pd.property_id',
                        'pd.property_image',
                        'pd.property_title',
                        'pd.city',
                        'pd.country',
                        'pd.space_type',
                        'pd.guest_limit',
                        'pd.property_views',
                        'd.id as deal_id',
                        'd.deal_type',                        
                        'd.amount as deal_amount', 
                        'pg.image_name as image', 
                        'pg.property_gallery_id as pg_id',  
                        (DB::raw('(SELECT min(pr.rate_per_week) FROM property_rate as pr WHERE pr.property_id=pd.property_id group by week(CURDATE())) week_rate')),
                        (DB::raw('(SELECT min(pr.rate_per_week) FROM property_rate as pr WHERE pr.property_id=pd.property_id and pr.start_date >= CURDATE() ) min_week_rate')),                        
                        (DB::raw('(SELECT count(d.id) FROM deals as d  WHERE d.to_date >= CURDATE()) deals_count')),
                        (DB::raw('(SELECT count(cpd.click_time)+1 FROM property_clicks as cpd  WHERE cpd.click_time >= CURDATE() - INTERVAL 1 DAY AND cpd.property_id=pd.property_id) last_one_day_record')),

                        (DB::raw('(SELECT count(property_id) FROM user_favourite_properties as fp WHERE fp.property_id=pd.property_id and fp.ip_address="'.$ip.'" group by fp.property_id, fp.ip_address) favourite_property')),

                        (DB::raw('(SELECT id FROM user_favourite_properties as fp WHERE fp.property_id=pd.property_id and fp.ip_address="'.$ip.'" group by fp.property_id)favourite_id')),

                        (DB::raw('(SELECT CAST(( CAST(sum(t.rating) AS UNSIGNED) / (count(t.rating)*5))* 100 AS UNSIGNED) FROM testimonials as t WHERE t.property_id=pd.property_id and t.status="publish" and t.admin_status="active") testimonial_rating')),


                        (DB::raw("(SELECT (CASE 
                            WHEN DATEDIFF(UTC_TIMESTAMP, cpd.property_view_time) != 0 THEN 
                                CASE 
                                    WHEN DATEDIFF(UTC_TIMESTAMP, cpd.property_view_time) > 1 THEN CONCAT(DATEDIFF(UTC_TIMESTAMP, cpd.property_view_time) ,' days ago') ELSE CONCAT(DATEDIFF(UTC_TIMESTAMP, cpd.property_view_time) ,' day ago') END
                            WHEN HOUR(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) != 0 THEN 
                                CASE
                                    WHEN HOUR(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) > 1 THEN CONCAT(HOUR(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) ,' hours ago') ELSE CONCAT(HOUR(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) ,' hour ago') END
                            WHEN MINUTE(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) != 0 THEN 
                                CASE
                                    WHEN MINUTE(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) > 1 THEN CONCAT(MINUTE(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) ,' minutes ago') ELSE CONCAT(MINUTE(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) ,' minute ago') END
                            ELSE
                                CASE
                                    WHEN SECOND(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) > 1 THEN CONCAT(SECOND(TIMEDIFF(UTC_TIMESTAMP, pd.property_view_time)) ,' seconds ago') ELSE 'now' END
                        END ) from property_details as cpd where cpd.property_id = pd.property_id) time_since"))
                )
                ->leftJoin('property_gallery as pg', 'pg.property_id','=','pd.property_id')
                ->leftJoin('deals as d', 'd.property_id', '=', 'pd.property_id')
                ->leftJoin('users as u', 'u.id', '=', 'pd.user_id')                
                ->whereRaw('pd.property_id = d.property_id')
                ->where("pd.verified", 'yes')
                ->where("pd.status", 'active')
                ->where('u.status', 'active')                
                ->whereRaw('d.to_date >= CURDATE()')
                ->orderBy('d.created_at', 'desc')
                ->groupBy('d.property_id')                
                ->get();               
                
        if($data){

            return $data;  
        }else{

            return '';
        }
    }

    public function getPropertyCountriesList(){

        $data = DB::table('property_details as pd')
                ->leftJoin('deals as d', 'd.property_id', '=', 'pd.property_id')
                ->leftJoin('users as u', 'u.id', '=', 'pd.user_id')
                ->select('pd.country')
                ->distinct('pd.country')
                ->where('u.status', 'active')
                ->whereRaw('d.to_date >= CURDATE()')
                ->whereRaw('pd.property_id = d.property_id')
                ->orderBy('pd.country', 'asc')
                ->get();

        if($data){

            return Response::json(array('success'=>1, 'message'=>'Countries found', 'data'=>$data), 200);   
        }else{

            return Response::json(array('success'=>0, 'message'=>'No Countries found'), 200);
        }
    }

    public function getPropertyCitiesByCountriesList(Request $request){

        $country = $request['country'];

        $data = DB::table('property_details')
                ->select('city')
                ->distinct('city')
                ->where('country', $country)
                ->orderBy('city', 'asc')
                ->get();

        if($data){

            return Response::json(array('success'=>1, 'message'=>'Cities found', 'data'=>$data), 200);   
        }else{

            return Response::json(array('success'=>0, 'message'=>'No Cities found'), 200);
        }
    }

    public function getLoadMoreDeals(Request $request){

        /*$page_count = $request['page_count'];*/
    }

    public function getFilterDealRequest(Request $request){
         


        $ip_address = $_SERVER['REMOTE_ADDR']; 
         
        if($ip_address=='::1'){
            $ip = '127.0.0.1';
        }else{
            $ip = $ip_address;
        }

        $searchPropertiesQuery = DB::table('property_details as pd')
                                 ->select('pd.*','d.deal_type','amount as deal_amount','pg.image_name', 'd.from_date', 'd.to_date',
                                    (DB::raw('(SELECT min(pr.rate_per_week) FROM property_rate as pr WHERE pr.property_id=pd.property_id group by week(CURDATE())) week_rate')),
                                    (DB::raw('(SELECT min(pr.rate_per_week) FROM property_rate as pr WHERE pr.property_id=pd.property_id and pr.start_date >= CURDATE() ) min_week_rate')),  
                                    (DB::raw('(SELECT count(cpd.click_time)+1 FROM property_clicks as cpd  WHERE cpd.click_time >= CURDATE() - INTERVAL 1 DAY AND cpd.property_id=pd.property_id) last_one_day_record')),
                                    (DB::raw('(SELECT count(d.id) FROM deals as d  WHERE d.to_date >= CURDATE()) deals_count')),
                                    (DB::raw('(SELECT count(property_id) FROM user_favourite_properties as fp WHERE fp.property_id=pd.property_id and fp.ip_address="'.$ip.'" group by fp.property_id, fp.ip_address) favourite_property')),

                                    (DB::raw('(SELECT id FROM user_favourite_properties as fp WHERE fp.property_id=pd.property_id and fp.ip_address="'.$ip.'" group by fp.property_id)favourite_id')),
                                    (DB::raw('(SELECT CAST(( CAST(sum(t.rating) AS UNSIGNED) / (count(t.rating)*5))* 100 AS UNSIGNED) FROM testimonials as t WHERE t.property_id=pd.property_id and t.status="publish" and t.admin_status="active") testimonial_rating')),
                                    (DB::raw("(SELECT (CASE 
                                                WHEN DATEDIFF(UTC_TIMESTAMP, cpd.property_view_time) != 0 THEN 
                                                    CASE 
                                                        WHEN DATEDIFF(UTC_TIMESTAMP, cpd.property_view_time) > 1 THEN CONCAT(DATEDIFF(UTC_TIMESTAMP, cpd.property_view_time) ,' days ago') ELSE CONCAT(DATEDIFF(UTC_TIMESTAMP, cpd.property_view_time) ,' day ago') END
                                                WHEN HOUR(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) != 0 THEN 
                                                    CASE
                                                        WHEN HOUR(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) > 1 THEN CONCAT(HOUR(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) ,' hours ago') ELSE CONCAT(HOUR(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) ,' hour ago') END
                                                WHEN MINUTE(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) != 0 THEN 
                                                    CASE
                                                        WHEN MINUTE(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) > 1 THEN CONCAT(MINUTE(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) ,' minutes ago') ELSE CONCAT(MINUTE(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) ,' minute ago') END
                                                ELSE
                                                    CASE
                                                        WHEN SECOND(TIMEDIFF(UTC_TIMESTAMP, cpd.property_view_time)) > 1 THEN CONCAT(SECOND(TIMEDIFF(UTC_TIMESTAMP, pd.property_view_time)) ,' seconds ago') ELSE 'now' END
                                            END ) from property_details as cpd where cpd.property_id = pd.property_id) time_since"))
                                 )
                                 ->leftJoin('users as u', 'u.id', '=', 'pd.user_id')
                                 ->leftJoin('deals as d', 'd.property_id', '=', 'pd.property_id')                              
                                 ->leftJoin('property_gallery as pg', 'pg.property_id', '=','pd.property_id');


        $deal_prop_id = array();

        if(isset($request['deals_datepicker']) && $request['deals_datepicker']){

            $time       = explode('-', $request['deals_datepicker']);
            $from_date  = date('Y-m-d', strtotime($time[0]));
            $to_date    = date('Y-m-d', strtotime($time[1]));
            
            
            if(isset($from_date) && isset($to_date)){           
                                                                               
                $searchPropertiesQuery->whereRaw("d.from_date >= '".$from_date."'"); 
                $searchPropertiesQuery->whereRaw("d.to_date   <= '".$to_date."'");  

            }    
        }
        

        if($request->has('city')){

            $searchPropertiesQuery->whereRaw("pd.city LIKE '%".$request['city']."%'"); 

        }

        if($request->has('country')){

            $searchPropertiesQuery->whereRaw("pd.country LIKE '%".$request['country']."%'"); 

        }
           

        $searchPropertiesQuery->whereRaw("pd.verified LIKE '%yes%'");
        $searchPropertiesQuery->whereRaw("pd.status LIKE '%active%'");
        $searchPropertiesQuery->whereRaw('d.to_date >= CURDATE()');
        $searchPropertiesQuery->where('u.status', 'active');
       // $searchPropertiesQuery->whereRaw('CURDATE() between d.from_date and d.to_date');
        $searchPropertiesQuery->whereRaw('d.property_id = pd.property_id');
        $searchPropertiesQuery->whereNotIn("pd.property_id", $deal_prop_id); 
        if($request['filter_type']=='latest'){

            $searchPropertiesQuery->orderBy('d.created_at', 'desc');

        }else if($request['filter_type']=='most_viewed'){


            $searchPropertiesQuery->orderBy(DB::Raw('MAX(d.deal_clicks)', 'desc'));  

        }else if($request['filter_type']=='best_deals'){

            $searchPropertiesQuery->orderBy(DB::raw("(CASE 
                                        WHEN d.deal_type='percentage' THEN d.amount*pd.standard_rate_per_week/100 
                                        WHEN d.deal_type='flat' THEN d.amount                     
                                    END)"), 'asc');
        }            
        $searchPropertiesQuery->groupBy('pd.property_id');
        
             

        $rdata = $searchPropertiesQuery->get(); 
        
        if($rdata){            

            return Response::json(array('success'=>1,'message'=>'success', 'data'=>$rdata));

        }else{

            return Response::json(array('success'=>0,'message'=>'error', 'property_details'=>'There are no properties with given requirement.'));
        }                                    
    }

    public function checkCouponsForProperty(Request $request)
    {
        
        $property_id     = $request['property_id'];

        $arrival_time    = $request['arrival_time'];

        $departure_time  = $request['departure_time'];
        $currency_name   = isset($request['currency_name'])?strtoupper($request['currency_name']):'';
        $prop_rates      = DB::table('deals as d')                        
                           //->select('d.*',"pr.rate_per_week","pr.rate_per_day")
                           ->select('d.*','pd.standard_rate_per_day','pd.standard_rate_per_week')
                           ->leftJoin("property_details as pd","pd.property_id","=","d.property_id")
                           ->where('d.property_id', $property_id)
                           //->whereBetween('from_date', [$arrival_time, $departure_time])
                           //->whereBetween('to_date', [$arrival_time, $departure_time])
                           //->orWhereRaw("date(d.from_date) >= '".date($arrival_time)."' and  date(d.to_date) <= '".date($arrival_time)."' ")
                           ->get();                          

        $result          = array();
        $response        = array();
        $currency_rate   = $currency_name=='EUR'?1:PropertyDetails::convertCurrency($currency_name); 
      if(count($prop_rates)>0){
        foreach ($prop_rates as $key => $pr1) {
            $rdates      = $this->checkBlockedDates($arrival_time, $departure_time);
            $current     = strtotime($pr1['from_date']);
            $last        = strtotime($pr1['to_date']); 
            while( $current <= $last ) {
                $dates[] = date('Y-m-d', $current);
                $current = strtotime('+1 day', $current);
            }
            $mdata1       = array_intersect($dates, $rdates);
            if(count($mdata1)>0){
                $prop_rates_new[] = $pr1;
            }else{
                $prop_rates_new1[] = $pr1;
            }
        }
      }else{
        $prop_rates_new1 = array(1);
      }  

        if(!isset($prop_rates_new)){ $prop_rates_new = array(); }
        if(!isset($prop_rates_new1)){ $prop_rates_new1 = array(); }

//echo "<pre>"; print_r($prop_rates_new1); print_r($prop_rates_new); exit;

        if(count($prop_rates_new) >0){
            foreach ($prop_rates_new as $pr) {

            //find property rates exist
            $pro_rat = DB::table("property_rate")
            ->whereRaw(" date(start_date) <= '".date($pr['from_date'])."'  and date(end_date)>= '".date($pr['to_date'])."'")
            ->where("property_id",$property_id)->first();
            $dates      = array();
            if(!empty($pro_rat)){
                $no_deal = "1";
                if(!empty($pro_rat["rate_per_week"])){
                    $day_cost = !empty($pro_rat['rate_per_week'])?round(($currency_rate*$pro_rat["rate_per_week"] / 7),2):'';
                }else{
                    $day_cost = !empty($pro_rat['rate_per_day'])?round(($currency_rate*$pro_rat["rate_per_day"]),2):'';
                }
                $current    = strtotime($pr['from_date']);
                $last       = strtotime($pr['to_date']); 
            }else{
                $no_deal = "2";
                if(!empty($pr["standard_rate_per_week"])){
                    $day_cost = !empty($pr['standard_rate_per_week'])?round(($currency_rate*$pr["standard_rate_per_week"] / 7),2):'';
                }else{
                    $day_cost = !empty($pr['standard_rate_per_day'])?round(($currency_rate*$pr["standard_rate_per_day"]),2):'';
                }
                $current    = strtotime($pr['from_date']);
                $last       = strtotime($pr['to_date']);
            }

            while( $current <= $last ) {
                $dates[] = date('Y-m-d', $current);
                $current = strtotime('+1 day', $current);
            }
            $rdates      = $this->checkBlockedDates($arrival_time, $departure_time);          
            $mdata       = array_intersect($dates, $rdates);  
            $offer_dates[] = $mdata;        
            $selected_dates = $rdates;
            $check_array = $rdates;

            //if(count($mdata)==count($check_array)){
               if(array_filter($mdata)){
                   $deal_dates                      = date('d-m-y',strtotime(reset($mdata))).' To '.date('d-m-y',strtotime(end($mdata)));
                   $no_deal_dates                   = count($selected_dates) - count($mdata);
                   $rdates['no_deal_dates']         = $no_deal_dates?$no_deal_dates:'null';
                   $rdates['deal_amount']          = $pr['amount'];
                   $rdates['deal_type']            = $pr['deal_type'];
                   $rdates['day_cost']              = sprintf("%.2f",$day_cost);//number_format($day_cost,2);
                   //$rdates['rate']                = round($day_cost) * count($mdata);
                    if(count($mdata)>1){
                        $mdata_count = count($mdata) - 1;
                    }else{
                        $mdata_count = count($mdata);
                    }
                   $rdates["original_rate"]         = $rdates['day_cost'] * $mdata_count;
                   $rdates['rate']                  = sprintf("%.2f",($rdates['day_cost'] * $mdata_count));//number_format(($day_cost * $mdata_count),2);
                   $rdates['discount_amount']       = "";
                   if(!empty($rdates['deal_type'])){
                    if($pr['deal_type']=="percentage"){
                        $rdates['discount_amount'] = number_format(($rdates['rate'] * ($pr['amount'] / 100)),2);
                       }else if($pr['deal_type']=="flat"){
                            if($rdates['rate'] > $pr['amount']){
                                $rdates['discount_amount'] = $pr['amount']; 
                            }else{
                                $rdates['discount_amount'] = 0;
                            }
                       }
                   }else{
                        $rdates['discount_amount'] = 0;
                   }
                   $rdates['selected_dates']        = count($selected_dates)?count($selected_dates):'null';
                   $rdates['db_deal_dates']         = count($dates)?count($dates):'null';
                   $rdates['deal_apply']            = count($mdata)?count($mdata):'null';
                   $rdates['deal_apply_dates']      = $deal_dates;
                   $response[] =  $rdates; 
                }else{ 
                   array_push($response,  '');
                } 
            //}
                       
        }
        }

        //echo "<pre>"; print_r($offer_dates); exit;
        if(isset($offer_dates)){
            foreach ($offer_dates as $key => $value) {
                foreach ($value as $key => $value1) {
                   $odates[] = $value1;
                }
            }
        }

        //echo "<pre>"; print_r($odates); exit;

        if(count($prop_rates_new1)>0){
            $prop_rat = DB::table("property_rate")
                        ->whereRaw(" date(start_date) <= '".date($arrival_time)."'  and date(end_date)>= '".date($departure_time)."'")
                        ->where("property_id",$property_id)->first();

            if($prop_rat){

                if(!empty($prop_rat["rate_per_week"])){
                    $day_cost1 = !empty($pro_rat['rate_per_week'])?round(($currency_rate*$prop_rat["rate_per_week"] / 7),2):'';
                }else{
                    $day_cost1 = !empty($pro_rat['rate_per_day'])?round(($currency_rate*$prop_rat["rate_per_day"]),2):'';
                }
                
            }else{

                $p_d = DB::table("property_details")->where("property_id",$property_id)->select('standard_rate_per_day','standard_rate_per_week')->first();
                if(!empty($p_d["standard_rate_per_week"])){
                    $day_cost1 = !empty($p_d['standard_rate_per_week'])?round(($currency_rate*$p_d["standard_rate_per_week"] / 7),2):'';
                }else{
                    $day_cost1 = !empty($p_d['standard_rate_per_day'])?round(($currency_rate*$p_d["standard_rate_per_day"]),2):'';
                }
            }
            $rdates1      = $this->checkBlockedDates($arrival_time, $departure_time);
            if(isset($odates)){
                $check = array_diff($rdates1,$odates); 
            }else{
                $check = $rdates1; 
            }
            //echo "<pre>"; print_r(explode(",",implode(",",$check))); exit;
            $check = explode(",",implode(",",$check));
            $last_date = count($check) - 1;
            $selected_dates1 = $check;
            $deal_dates                     = date('d-m-y',strtotime($check[0])).' To '.date('d-m-y',strtotime($check[$last_date]));
            $no_deal_dates                  = 0;
            $rdates['no_deal_dates']        = 'null';
            $rdates['deal_amount']          = 0;
            $rdates['deal_type']            = "";
            $rdates['day_cost']             = sprintf("%.2f",$day_cost1);//number_format($day_cost1,2);
            if(count($selected_dates1)>1){
            $mdata_count = count($selected_dates1) - 1;
            }else{
            $mdata_count = count($selected_dates1);
            }
            $rdates['days_count']           = $mdata_count;
            $total_cost                     = $rdates['day_cost'] * $mdata_count;
            $rdates["original_rate"]        = $total_cost;
            $rdates['rate']                 = sprintf("%.2f",$total_cost);//number_format(($day_cost1 * $mdata_count),2);
            $rdates['discount_amount']      = "";
            $rdates['discount_amount']      = 0;
            $rdates['selected_dates']       = count($selected_dates1)?count($selected_dates1):'null';
            $rdates['db_deal_dates']        = count($rdates1)?count($rdates1):'null';
            $rdates['deal_apply']           = 'null';
            $rdates['deal_apply_dates']     = $deal_dates;
            $response[]                     =  $rdates;
        
        }

          $response_result = array_filter($response);
           
          if(count($response_result)){
            
               return Response::json(array('success'=>1, 'message'=>'Selected dates has deal!', 'data'=>$response_result), 200);
          }else{

               return Response::json(array('success'=>0, 'message'=>'Selected dates has no deal!'), 200);                
          }
    }

    function checkBlockedDates($start, $end){

        $dates      = array();
        $current    = strtotime($start);
        $last       = strtotime($end);

        while( $current <= $last ) {

            $dates[] = date('Y-m-d', $current);
            $current = strtotime('+1 day', $current);
        }

        return $dates;
            
    }

    public function getDealPropertyData($prop_id){

        $data = DB::table('property_details')
                ->select('country', 'city')
                ->where('property_id', $prop_id)
                ->first();

        return $data;
    }

    public function checkCouponsForPropertyAvailability(Request $request){        
        
        	
		$ip_address    = $_SERVER['REMOTE_ADDR']; 
		$currency_name = isset($request['currency_name'])?strtoupper($request['currency_name']):'';
		$set_timezone  = json_decode(file_get_contents('http://ip-api.com/json/'.$ip_address)); 
		$get_timezone  = isset($set_timezone->timezone)?$set_timezone->timezone:'Asia/Kolkata';
		
		date_default_timezone_set($get_timezone);
		
		$from_date      = date('Y-m-d H:i:s');//$request['from_date'];

        $to_date        = date('Y-m-d H:i:s');//$request['to_date'];     

        $deal_prop_data = $this->getDealPropertyData($request['property_id']);

        $check_selected_dates_has_coupon = DB::table('flash_sales')
                                           ->select('*')
                                           ->whereRaw('to_date >= "'.$from_date.'"')
                                           ->whereRaw('from_date <="'.$to_date.'"')
                                           ->get();     

        $currency_rate                   = $currency_name=='EUR'?1:PropertyDetails::convertCurrency($currency_name); 
        if(!$check_selected_dates_has_coupon){

            return Response::json(array('success'=>3, 'message'=>'No Coupon Applicable'), 200);
        }
        else if($check_selected_dates_has_coupon)
        {   

            $check_coupon_data  = DB::table('flash_sales')                                  
                                    ->select('*')                                 
                                    ->whereRaw('coupon_code="'.$request['coupon'].'"')
                                    ->first();                      

            $couponsQuery   = DB::table('flash_sales as fs')                        
                                ->select('fs.*')                                 
                                ->whereRaw('fs.coupon_code="'.$request['coupon'].'"');
                 
            
            if(isset($check_coupon_data['country']) && isset($check_coupon_data['city']) && $check_coupon_data['country'] && $check_coupon_data['city']) {
                              
                
                $propCity    = $deal_prop_data['city'];

                $propCountry = $deal_prop_data['country'];
                
                $couponsQuery->whereRaw('fs.country like "%'.$propCountry.'%"');

                $couponsQuery->whereRaw('fs.city like "%'.$propCity.'%"');

                $coupons = $couponsQuery->first();

            }else if(isset($check_coupon_data['country']) && $check_coupon_data['country'] && isset($check_coupon_data['city']) && !$check_coupon_data['city'])
            {                   

                $propCountry = $deal_prop_data['country'];
                
                $couponsQuery->whereRaw('fs.country like "%'.$propCountry.'%"');

                $coupons = $couponsQuery->first();

            }else if(isset($check_coupon_data['country']) && !$check_coupon_data['country'] && isset($check_coupon_data['city']) && !$check_coupon_data['city']){

                $coupons = $couponsQuery->first();
                
            }else{

                $coupons = '';
            }                                       
            
            $check_coupon_time = DB::table('flash_sales')
                                ->select('*')    
                                ->whereRaw('coupon_code="'.$request['coupon'].'"')
                                ->whereRaw('to_date >= "'.$from_date.'"')
                                ->whereRaw('from_date <="'.$to_date.'"')
                                ->first();                          

            
            $check_coupon = DB::table('flash_sales')
                            ->select('coupon_code')    
                            ->whereRaw('coupon_code="'.$request['coupon'].'"')
                            ->first();

            
            if($coupons && $check_coupon && $check_coupon_time){
                

                $result     = array();
                $response   = array();              
                    
                $dates      = array();
                $current    = strtotime($coupons['from_date']);
                $last       = strtotime($coupons['to_date']);          


                while( $current <= $last ) {

                    $dates[] = date('Y-m-d', $current);
                    $current = strtotime('+1 day', $current);
                }
                       

                $mdata       = in_array(date('Y-m-d'), $dates);  
                
                if($mdata){
                      
                    $response_result['type']         =  $coupons['discount_type'];
                    //$response_result['amount']       =  $coupons['discount_amount'];
                    //$response_result['min_amount']   =  $coupons['minimum_value'];
                    $response_result['amount']       =  !empty($coupons['discount_amount'])?round(($currency_rate*$coupons['discount_amount']),2):''; 
                    $response_result['min_amount']   =  !empty($coupons['minimum_value'])?round(($currency_rate*$coupons['minimum_value']),2):'';
                    return Response::json(array('success'=>1, 'message'=>'Valid coupon', 'data'=>$response_result), 200);
                }else{

                    $check_coupon_validity = $this->checkCouponValidity($request, $deal_prop_data);

                    return $check_coupon_validity;                
                } 
            }else if(!$coupons && $check_coupon_time['country']=='' && $check_coupon_time['city']=='' && $check_coupon && $check_coupon_time)
            {
            	$response_result['type']         =  $check_coupon_time['discount_type'];
                //$response_result['amount']       =  $check_coupon_time['discount_amount'];
                //$response_result['min_amount']   =  $check_coupon_time['minimum_value'];
                $response_result['amount']       =  !empty($check_coupon_time['discount_amount'])?round(($currency_rate*$check_coupon_time['discount_amount']),2):''; 
                $response_result['min_amount']   =  !empty($check_coupon_time['minimum_value'])?round(($currency_rate*$check_coupon_time['minimum_value']),2):'';
                return Response::json(array('success'=>1, 'message'=>'Valid coupon', 'data'=>$response_result), 200);
            }
            else if(!$check_coupon && $check_coupon_time){

                return Response::json(array('success'=>2, 'message'=>'Sorry, coupon not valid!'), 200);
                
            }else if($check_coupon && !$check_coupon_time){


                return Response::json(array('success'=>2, 'message'=>'Sorry, coupon expired!'), 200);
            }
            else{

                $check_coupon_validity = $this->checkCouponValidity($request, $deal_prop_data);

                return $check_coupon_validity;
                
            }            

        }else{

            return Response::json(array('success'=>2, 'message'=>'Coupon is empty!'), 200);

        }        
        
    }

    public function checkCouponValidity($input, $prop_data){

        $coupon = DB::table('flash_sales')
                  ->select('*')
                  ->whereRaw('coupon_code="'.$input['coupon'].'"')
                  ->first();
                 

        if($coupon){         
            $city       = isset($prop_data['city'])?$prop_data['city']:'';
            $country    = isset($prop_data['country'])?$prop_data['country']:'';
            

            if($coupon['city']==$city && $coupon['country']==$country)
            {
               
                return Response::json(array('success'=>0, 'message'=>'Coupon not valid!'), 200);
                
            }else if($coupon['city']=='' && $coupon['country']==$country){
                
                $message = "Coupon valid only for ".$coupon['country'].' property';

                return Response::json(array('success'=>0, 'message'=>$message), 200);
            }else if($coupon['city']=='' && $coupon['country']!=$country){

                $message = "Coupon valid only for ".$coupon['country'].' property';

                return Response::json(array('success'=>0, 'message'=>$message), 200);
            }
            else{

                $message = "Coupon valid only for ".$coupon['city'].", ".$coupon['country'];

                return Response::json(array('success'=>0, 'message'=>$message), 200);
                
            }
            
        }else{

            return Response::json(array('success'=>0, 'message'=>'Coupon not valid!'), 200);
        }            
    }

    public function getOwnerFilterDeals(Request $request){

        $property_id    = $request['property_id'];

        $dealQuery      = DB::table('deals as d')
                            ->select(
                                'd.*',
                                'pd.property_title',
                                DB::raw('DATE_FORMAT(d.from_date, "%d/%m/%y") as from_date'),
                                DB::raw('DATE_FORMAT(d.to_date, "%d/%m/%y") as to_date')
                            )
                            ->leftJoin('property_details as pd', 'pd.property_id', '=', 'd.property_id')
                            ->leftJoin('users as u', 'u.id', '=', 'pd.user_id')
                            ->where('u.status', 'active')
                            ->where('owner_id', $request['owner_id']);
                    

        if($request->has('property_id') && $request['property_id']!='undefined'){

            $dealQuery->where('d.property_id', $property_id);
        }                    
        
        if($request['date']!='undefined'){

            $deal_date      = explode('-',$request['date']);
            $from_date      = date('Y-m-d', strtotime($deal_date[0]));
            $to_date        = date('Y-m-d', strtotime($deal_date[1]));    

            $dealQuery->whereRaw("d.from_date >= '".$from_date."' and d.to_date <= '".$to_date."'");
        }
        
        $dealQuery->orderBy('d.created_at', 'desc');
        $data = $dealQuery->get();

        
        if($data)
        {
            return Response(array('success'=>1, 'message'=>'Deals found', 'data' =>$data), 200);
        }else{

            return Response(array('success'=>0, 'message'=>'Deals not found'), 200);
        }
    } 

    public function getPropertyOtherDeals(Request $request){

        $prop_id = $request['prop_id'];

        $deals   = DB::table('deals as d')
                   ->leftJoin('property_details as pd', 'd.property_id', '=', 'pd.property_id') 
                   ->leftJoin('users as u', 'u.id', '=', 'pd.user_id')
                   ->select(
                        'd.deal_type',
                        'd.id as deal_id',
                        'd.property_id',
                        (DB::raw('(SELECT min(pr.rate_per_week) FROM property_rate as pr WHERE pr.property_id="'.$prop_id.'" group by week(CURDATE())) week_rate')),
                        (DB::raw('(SELECT min(pr.rate_per_week) FROM property_rate as pr WHERE pr.property_id="'.$prop_id.'" and pr.start_date >= CURDATE() ) min_week_rate')),  
                        'd.amount as deal_amount',
                        DB::raw('DATE_FORMAT(d.from_date, "%d/%m/%y") as from_date'),
                        DB::raw('DATE_FORMAT(d.to_date, "%d/%m/%y") as to_date'),
                        'pd.property_title'
                    )
                   ->where('u.status', 'active')
                   ->where('d.property_id', $prop_id)
                   ->whereRaw('d.to_date >= CURDATE()')
                   ->get();
        
        if($deals){

            return Response(array('success'=>1, 'message'=>'Upcoming Deals found', 'data' =>$deals), 200);
        }else{

            return Response(array('success'=>0, 'message'=>'Upcoming Deals not found'), 200);
        }
    }

    public function savePropertyDealClicks(Request $request){

        $request = $request->all();       

        if(isset($request['num'])){
            $views = DB::table('deals')
                    ->select('deal_clicks')    
                    ->where('id', $request['deal_id'])
                    ->first();

            $view_count     = $views['deal_clicks']+1;
            $time           = date('Y-m-d H:i:s');
                


            DB::table('deal_views')
                ->insertGetId(array(
                    'property_id'   =>$request['property_id'],
                    'deal_id'       =>$request['deal_id'],   
                    'created_at'    =>$time                   
                ));            

            $saveObj =  DB::table('deals')
                            ->where('id', $request['deal_id'])
                            ->update(array('deal_clicks'=>$view_count, 'created_at'=>$time, 'updated_at'=>$time));
            return $request['deal_id'];                                     

        }
    } 

    public function getPropertyDealDates(Request $request){

        $prop_id = $request['property_id'];


        $data = DB::table('deals')
                ->select('from_date', 'to_date')                
                ->where('property_id', $prop_id)                
                ->get();                            

        if($data){             

            return Response::json(array('success'=>'1', 'details'=>$data));

        }else{

            return Response::json(array('success'=>'0', 'details'=>'No deals dates are booked'));
        }
    } 

    public function getCheckDealHelpPdf(){

        $path = public_path().'/uploads/deal_help_text.pdf';
        
        if(file_exists($path)){

            return Response::json(array('success'=>'1'));
        }else{
            return Response::json(array('success'=>'0'));
        }
    }
}
