<?php

namespace App\Http\Controllers\Api\Properties;
use Intervention\Image\Facades\Image as Image;
use Illuminate\Support\Facades\Storage;
use App\Http\Controllers\Controller;

use Illuminate\Http\Request;

use App\PropertyDetails;

use App\PropertyRate;

use App\PropertyClicks;

use App\User;

use App\PropertyPreblockDetails;

use App\PropertyGallery;

use App\Http\Requests;

use Carbon\Carbon;

use Validator;

use Response;

use DateTime;

use DatePeriod;

use DateInterval;

use DB;

use Mail;

use Log;

use GuzzleHttp\Client;

use Swagger\Client\Configuration as SwaggerConfiguration;

use Swagger\Client\Api\ScanApi as SwaggerScanApi;
use Config;
class PropertyDetailsController extends Controller
{

    public function __construct(){
      
       $this->from_email             = Config::get('app.email_from_address');
       $this->_s3_path               = Config::get('filesystems.s3_path');
    }

    public function getAWSLink(Request $request){

        $_s3_path = $this->_s3_path;

        if($_s3_path){

            return Response::json(array('success'=>1, '_s3_path'=>$_s3_path));
        }else{

            return Response::json(array('success'=>0));
        }
    }

    public function getRecentPropertiesList($id, Request $request){

        $ip_address = $_SERVER['REMOTE_ADDR']; 
        if($ip_address=='::1'){
            $ip = '127.0.0.1';
        }else{
            $ip = $ip_address;
        }

        $selected_currency = isset($request['selected_currency'])?strtoupper($request['selected_currency']):'';
        $page_title        = isset($request['page'])?$request['page']:'';

    	$properties        = PropertyDetails::getRecentPropertiesList($id, trim($selected_currency), $page_title);

    	if($properties){             

            return Response::json(array('message'=>'success', '_s3_path'=>$this->_s3_path, 'ip_address'=>$ip, 'properties_details'=>$properties));

        }else{

            return Response::json(array('message'=>'error', '_s3_path'=>$this->_s3_path, 'property_details'=>'There are no properties.'));
        }
    	
    } 

    public function getSinglePropertyDetailsById($id){     

        $deal_id = isset($_GET['deal_id'])?$_GET['deal_id']:'';    
        $currency_name = isset($_GET['currency_name'])?$_GET['currency_name']:'eur';
        $currency_symbol = isset($_GET['currency_symbol'])?$_GET['currency_symbol']:'';     

    	$property = PropertyDetails::getSinglePropertyDetailsById($id, $deal_id, strtoupper($currency_name), $currency_symbol);

        if($property){
                        
            return Response::json(array('message'=>'success', '_s3_path'=>$this->_s3_path, 'property'=>$property));

        }else{
            
            return Response::json(array('message'=>'error', '_s3_path'=>$this->_s3_path, 'property_details'=>'No property found with the given requirement, Please try another'));
        }    	
    }

    public function getUserSimilarProperties(Request $request){

    	$request = $request->all();

    	$propertyRule = array('owner_id'=>'required');

    	$validator = Validator::make(

            $request, $propertyRule
            
        );
    	if(!$validator->fails()){

    		$properties = PropertyDetails::getUserSimilarProperties($request);

    		return $properties;

    	}else{

    		return Response::json(array('success'=>0, 'message'=>$validator->getMessageBag()->first()), 400);
    	}    				 
    }

    public function getSimilarPropertiesByLocation(Request $request){

        $request = $request->all();
        Log::info(print_r($request, true));
        $id = isset($request['id'])?$request['id']:'';
        $latitude = isset($request['latitude'])?$request['latitude']:'';
        $longitude = isset($request['longitude'])?$request['longitude']:'';
        $currency_name = isset($request['currency_name'])?strtoupper($request['currency_name']):'';
        $currency_symbol = isset($request['currency_symbol'])?$request['currency_symbol']:'';
        $data = PropertyDetails::getSimilarPropertiesByLocation($id, $latitude, $longitude, $currency_name, $currency_symbol);

        return $data;
    }

    public function getSearchPageResults(Request $request){       
        
        $results = PropertyDetails::getUserSearchResults($request);

        if($results){            

            return Response::json(array('message'=>'success', '_s3_path'=>$this->_s3_path, 'properties_details'=>$results));

        }else{

            return Response::json(array('message'=>'error', '_s3_path'=>$this->_s3_path, 'property_details'=>'There are no properties with given requirement.'));
        }  

    }

    public function addProperty(Request $request){
        //print_r($request['image_name']);die();

        $property = PropertyDetails::addPropertyDetails($request);

        return $property;
        // $propertyRule = array(
        //     'main_image_name'=>'mimes:jpg,jpeg,png|file|max:2192',
        //     'image_name.*' => 'mimes:jpg,jpeg,png|max:3192'
        // );

        // $validator = Validator::make(

        //     $request, $propertyRule
            
        // );
        // if(!$validator->fails()){

        //     $property = PropertyDetails::addPropertyDetails($request);

        //     return $property;

        // }else{

        //     return Response::json(array('success'=>0, 'message'=>$validator->getMessageBag()->first()), 200);
        // } 

        

    }

    public function deletePropertyDetails(Request $request){
        $request = $request->all();

        $propertyRule = array('property_id'=>'required');

        $validator = Validator::make(

            $request, $propertyRule
            
        );
        if(!$validator->fails()){

            $properties = PropertyDetails::getDeletePropertyDetailsById($request);

            return $properties;

        }else{

            return Response::json(array('success'=>0, 'message'=>$validator->getMessageBag()->first()), 400);
        } 

    }

    public function editPropertyDetails(Request $irequest){ 

        $request = $irequest->all();

        $propertyRule = array(
            'property_id'=>'required',
            // 'main_image_name'=>'mimes:jpg,jpeg,png|file|max:2192',
            // 'image_name.*' => 'mimes:jpg,jpeg,png|max:3192'
        );

        $validator = Validator::make(

            $request, $propertyRule
            
        );
        if(!$validator->fails()){

            $properties = PropertyDetails::editPropertyDetails($irequest);

            return $properties;

        }else{
            Log::info(print_r($validator->getMessageBag()->first(), true));
            return Response::json(array('success'=>0, 'message'=>$validator->getMessageBag()->first()), 200);
        }

    }

    public function getAllPropertiesDetails(Request $request){

        $property = PropertyDetails::getPropertiesDetails($request);

        return $property;
    }

    public function getMinMaxValues(){

        $data = PropertyDetails::getMinMaxValues();

        return $data;
    }

    public function getUserPropertiesDashborad(Request $request){

        $request = $request->all();

        $propertyRule = array('user_id'=>'required');

        $validator = Validator::make(

            $request, $propertyRule
            
        );
        if(!$validator->fails()){

            $properties = PropertyDetails::getUserPropertiesDashborad($request);

            if($properties){

                return Response::json(array('success'=>'1', '_s3_path'=>$this->_s3_path,  'properties_details'=>$properties));

            }else{

                return Response::json(array('success'=>'0', '_s3_path'=>$this->_s3_path, 'properties_details'=>'No results found'));
            } 

        }else{

            return Response::json(array('success'=>0, 'message'=>$validator->getMessageBag()->first()), 400);
        }
    }

    /*public function getAllActivePropertiesDetails(){

        $property = PropertyDetails::getActivePropertiesDetails();

        return $property;
    }

    public function getAllInActivePropertiesDetails(){

        $property = PropertyDetails::getInActivePropertiesDetails();

        return $property;
    }*/

    public function getOwnerDashboardStats(Request $request){

        $request = $request->all();

        $dashboardStatsRules = array('owner_id'=>'required');

        $validator = Validator::make(

            $request, $dashboardStatsRules
            
        );
        if(!$validator->fails()){

            $dashboardStats = PropertyDetails::getOwnerDashboardStats($request);

            return $dashboardStats;

        }else{

            return Response::json(array('success'=>0, 'message'=>$validator->getMessageBag()->first()), 400);
        }
    }

    public function getCountriesList(){

        $countries = PropertyDetails::getCountriesList();

        return $countries;
    }

    public function getCitiesByCountry(Request $request){  

        $request = $request->all();

        $cityRules = array('country_id'=>'required');

        $validator = Validator::make(

            $request, $cityRules
            
        );        

        if(!$validator->fails()){

            $id = $request['country_id'];

            $cities = PropertyDetails::getCitiesByCountry($id);

            return $cities;

        }else{

            return Response::json(array('success'=>0, 'message'=>$validator->getMessageBag()->first()), 400);
        }
    }

    public function getRecordCount(Request $request){

        $property = PropertyDetails::where('property_id', '=', $request['property_id'])->where('verified', 'yes')->where('status', 'active')->first();
        if($property){

            return '1';
        }else{
            return '0';
        }
    }

    public function getCitiesToSearch(){

        $cities = PropertyDetails::getCitiesListToSearch();

        return $cities;
    }

    public function getAllPropertiesDetailsList(){

        $property = PropertyDetails::getAllPropertiesDetailsList();

        return $property;
    }

    public function deletePropertyRate(Request $request){

        $rateId = $request['property_rate_id'];

        $property = PropertyRate::deletePropertyRate($rateId);

        return $property;
    }    

    public function deletePropertyImage(Request $request){

        $rateId = $request['property_gallery_id'];

        $property = PropertyGallery::deletePropertyImageFromGallery($rateId);

        if($property){             

            return Response::json(array('success'=>'1', 'message'=>'Image deleted successfully!'));

        }else{

            return Response::json(array('success'=>'0', 'message'=>'Image not deleted please try again!'));
        }
    }

    public function savePreblockProperty(Request $request){
        Log::info(print_r('here preblock', true));
        $preblock = $this->savePreblockPropertyInDB($request);
        Log::info(print_r($preblock, true));
        return $preblock;
    }

    public  function savePreblockPropertyInDB($request){
        
        $preblock_property = new PropertyPreblockDetails;       

        $checkDates = $this->checkPropertyPreblockDetails($request);
        
        if($checkDates){

            return Response::json(array('success'=>'2', 'message'=>'You cannot add property some dates are blocked already'));
            
        }else{

            if(isset($request['property_id'])){

                $property_id = $request['property_id'];
            }

            if(isset($request['start_date'])){

                $start_date = $request['start_date'];
            }

            if(isset($request['end_date'])){

                $end_date = $request['end_date'];
            }

            if(isset($request['preblock_comment'])){

                $preblock_comment = $request['preblock_comment'];
            }           

            $rate = isset($request['rate'])?$request['rate']:'';            
            
            $preblock_property = DB::table('property_preblock_details')->insertGetId([
                                'property_id'=>$property_id,
                                'start_date' =>$start_date,
                                'end_date'   =>$end_date,
                                'rate'       =>$rate,
                                'comment'    =>$preblock_comment
                                ]);

            $book_property    = DB::table('booknow_property_details')->insertGetId([
                                'property_id'       =>$property_id,
                                'arrival_time'      =>$start_date,
                                'departure_time'    =>$end_date,
                                'payment_status'    =>'yes',
                                'preblock_id'       =>$preblock_property,
                                'block_type'        =>'preblock',
                                'preblock_comment'  =>$preblock_comment
                                ]);
            Log::info(print_r('pre block', true));
            Log::info(print_r($book_property, true));
            if($preblock_property){

                $details = PropertyPreblockDetails::getPreblockPropertyDetailsById($preblock_property);
                return Response::json(array('success'=>'1', 'message'=>'Reserved dates details saved successfully!', 'details'=>$details));
            }else{

                return Response::json(array('success'=>'0', 'message'=>'Reserved dates details not saved!'));
            } 
        }
        
    }

     public function checkPropertyPreblockDetails($request){
        
        $existingDates = $this->getExistingPropertyDetails($request['property_id']);
        
        $start  = new DateTime($request['start_date']);
        $end    = new DateTime($request['end_date']);

        $daterange = new DatePeriod($start, new DateInterval('P1D'), $end);
        $data = array();

        foreach($daterange as $date){
            array_push($data, $date->format("Y-m-d"));
        }
        
        if($existingDates){ 

            $result = count(array_intersect($data, $existingDates));

            return $result;
        }else{
            return 0;
        }
        
    }

    public function getExistingPropertyDetails($id){

        /*$dates = DB::table('property_preblock_details as ppd')
            ->select('ppd.id', 'ppd.property_id', 'ppd.start_date', 'ppd.end_date', 'pbd.arrival_time as start_date', 'pbd.departure_time as end_date')
            ->leftJoin('booknow_property_details as pbd', 'pbd.property_id', '=', 'ppd.property_id')
            ->where('ppd.property_id', $id)
            ->where('pbd.payment_status', 'yes')
            ->get();*/

         $dates =  DB::table('booknow_property_details as pbd')
                ->select('ppd.id', 'ppd.property_id', 'ppd.start_date', 'ppd.end_date', 'pbd.arrival_time as start_date', 'pbd.departure_time as end_date')
                ->leftJoin('property_preblock_details as ppd', 'ppd.property_id', '=', 'pbd.property_id')
                ->where('pbd.property_id', $id)
                ->where('pbd.payment_status', 'yes')
                ->where('pbd.owner_cancel_request','!=', 'no')
                ->where('pbd.admin_cancel_status','!=', 'yes')
                ->get();
                              
        if(count($dates)){
            $data = array();
            $dates_arr      = array();
            foreach ($dates as $d) {
                
                
                $current        = strtotime($d['start_date']);
                $last           = strtotime($d['end_date']);
                $output_format  = 'Y-m-d';
                $step           = "+1 day";
                while( $current <= $last ) {

                    $dates_arr[] = date($output_format, $current);
                    $current = strtotime($step, $current);
                }              
                
            }   

            return $dates_arr;
        }else{                
            return 0;
        }               

    }

    public function getAllOwnerPreblockPropertyDetails($id){

        $preblock = PropertyPreblockDetails::getAllOwnerPreblockPropertyDetails($id);

        return $preblock;   
    }

    public function getAllPreblockPropertyDetails(Request $request, $action = null, $id = null){
        Log::info(print_r($action.'action', true));
        Log::info(print_r($id.'id', true));
        if($action=='view'){

            $preblock = PropertyPreblockDetails::getAllPreblockPropertyDetails();
            return $preblock;  
        }    
        if($action=='delete'){
            
            //$preblock = PropertyPreblockDetails::deletePreblockPropertyDetails($id);
            $data       = DB::table('property_preblock_details')->where('id', $id)->delete();
            $preblock   = DB::table('booknow_property_details')->where('preblock_id', $id)->delete();
            if($data && $preblock){

                return Response::json(array('success'=>'1', 'message'=>'Reserved dates details deleted'));
            }else{

                return Response::json(array('success'=>'0', 'message'=>'Reserved dates details not deleted!'));
            }
        }
        Log::info(print_r($preblock, true));
         
    }

    public static function getPreblockPropertyBlockedDates($id){

        /*$data = DB::table('property_preblock_details as ppd')
                ->select('ppd.id', 'ppd.property_id', 'ppd.start_date', 'ppd.end_date', 'pbd.arrival_time as start_date', 'pbd.departure_time as end_date')
                ->leftJoin('booknow_property_details as pbd', 'pbd.property_id', '=', 'ppd.property_id')
                ->where('ppd.property_id', $id)
                ->where('pbd.payment_status', 'yes')
                ->toSql();*/

        $data = DB::table('booknow_property_details as pbd')
                ->select(
                    'pbd.block_type',
                	'pbd.id', 
                	'pbd.property_id',                	
                	DB::raw('DATE_FORMAT(pbd.arrival_time, "%Y/%m/%d") as start_date'), 
                	DB::raw('DATE_FORMAT(pbd.departure_time, "%Y/%m/%d") as end_date'),
                    (DB::raw("(CASE 
                        WHEN pbd.block_type='banking' THEN DATE_FORMAT(DATE_SUB(pbd.departure_time,INTERVAL 1 DAY), '%Y/%m/%d') 
                        WHEN pbd.block_type!='banking' THEN DATE_FORMAT(pbd.departure_time, '%Y/%m/%d')   
                                    
                    END) send_date")) 
                	)                
                ->where('pbd.property_id', $id)
                ->where('pbd.payment_status', 'yes')
                ->where('pbd.owner_cancel_request','!=', 'no')
                ->where('pbd.admin_cancel_status','!=', 'yes')                
                ->get();        
		
		//echo $data;                 

        if($data){             

            return Response::json(array('success'=>'1', 'details'=>$data));

        }else{

            return Response::json(array('success'=>'0', 'details'=>'No dates are booked'));
        }            

    } 

    public function getPropertyRateBlockedDates($id){

        $data = DB::table('property_rate as pr')
                ->select(
                    'pr.property_rate_id', 
                    'pr.property_id',
                    DB::raw('DATE_FORMAT(pr.start_date, "%Y/%m/%d") as start_date'),
                    DB::raw('DATE_FORMAT(pr.end_date, "%Y/%m/%d") as end_date')                    
                    )                
                ->where('pr.property_id', $id)                
                ->get();   

        if($data){             

            return Response::json(array('success'=>'1', 'details'=>$data));

        }else{

            return Response::json(array('success'=>'0', 'details'=>'No dates are booked'));
        }
    }

    public function getAdminPropertyRateBlockedDates($id){

        $data = DB::table('property_rate as pr')
                ->select(
                    'pr.property_rate_id', 
                    'pr.property_id',
                    DB::raw('DATE_FORMAT(pr.start_date, "%Y/%m/%d") as start_date'),
                    DB::raw('DATE_FORMAT(pr.end_date, "%Y/%m/%d") as end_date')                    
                    )                
                ->where('pr.property_id', $id)                
                ->get();   

        if($data){             

            return Response::json(array('success'=>'1', 'details'=>$data));

        }else{

            return Response::json(array('success'=>'0', 'details'=>'No dates are booked'));
        }
    }

    public function savePropertyEveryClick(Request $request){

        $updated_time   = date('Y-m-d H:i:s');

        $updateObj =  DB::table('property_details as pd')
                    ->where('pd.property_id', $request['property_id'])
                    ->update(array('property_view_time'=>$updated_time)); 

        return $updateObj;
    }

    public function savePropertyClicks(Request $request){

        $request = $request->all();       

        if(isset($request['num'])){
            $views = DB::table('property_details')
                    ->select('property_views')    
                    ->where('property_id', $request['property_id'])
                    ->first();

            $view_count     = $views['property_views']+1;
            $updated_time   = date('Y-m-d H:i:s');
            $click_time     = date('Y-m-d');    


            DB::table('property_clicks')
                ->insertGetId(array(
                    'property_id'=>$request['property_id'],
                    'click_time'=>$updated_time                   
                ));            

            $saveObj =  DB::table('property_details as pd')
                            ->where('pd.property_id', $request['property_id'])
                            ->update(array('property_views'=>$view_count, 'property_view_time'=>$updated_time, 'property_click_time'=>$click_time));
            return $request['property_id'];                                     

        }
    }

    public function getUpdatePreblockComment(Request $request){

        $preblock_id = $request['preblock_id'];

        $update = DB::table('property_preblock_details')
                  ->where('id', $preblock_id)  
                  ->update(
                    array('comment' => $request['comment']));
        
        if($update)
        {
            return Response::json(array('success'=>1, 'message'=>'Comment submitted successfully!'));
        }else{

            return Response::json(array('success'=>0, 'message'=>'Comment not submitted, Please try again'));
        }
    }

    public function getOnLoadCPropertyCountriesList(Request $request){

    	$data = DB::table('property_details as pd')
                ->leftJoin('users as u', 'u.id', '=', 'pd.user_id')
                ->select('pd.country')
                ->distinct('pd.country')
                ->where('u.status', 'active')
                ->where('verified', 'yes')
                ->where('pd.status', 'active')
                ->orderBy('pd.country', 'asc')
                ->get();

        if($data){

            return Response::json(array('success'=>1, 'message'=>'Countries found', 'data'=>$data), 200);   
        }else{

            return Response::json(array('success'=>0, 'message'=>'No Countries found'), 200);
        }
    }

    public function getPropertyCityByCountriesList(Request $request)
    {	

    	$country = $request['country']!=''?$request['country']:'';

    	$citiesQuery = DB::table('property_details as pd')
    				  ->leftJoin('users as u', 'u.id', '=', 'pd.user_id')	
                      ->select(
                      		'pd.city',
                            'pd.country',
                      		DB::raw('count(pd.property_id)')
                      	)
                      ->groupBy('pd.city')
                      ->distinct('pd.city');
		if($country){

			$citiesQuery->whereRaw("pd.country = '". $country ."'");
		}  

        $cities 	= $citiesQuery->whereRaw('pd.status = "active"')
                    	->whereRaw('pd.verified = "yes"')
                    	->whereRaw('pd.city !=""')
                    	->whereRaw('u.status = "active"')
                    	->orderByRaw('count(pd.property_id) DESC')
                    	->orderBy('pd.city', 'asc')
                    	->skip(0)
                    	->take(10) 
                    	->get();

    	//$cities = DB::select("select distinct pd.city, COUNT(property_id) from property_details as pd left join users as u on u.id=pd.user_id where pd.city != '' and pd.status ='active' and pd.country='".$country."' and u.status='active' group by pd.city order by count(property_id) DESC, pd.city asc limit 0,10");

          
        if($cities){

            return Response::json(array('success'=>'1', 'cities'=>$cities));

        }else{
            
            return Response::json(array('success'=>'0', 'countries'=>'No cities are there!'));                                               
        }
    }

    public function getPropertyCountriesByCityList(Request $request){

        $city = $request['city']!=''?$request['city']:'';


        $citiesQuery = DB::table('property_details as pd')
                      ->leftJoin('users as u', 'u.id', '=', 'pd.user_id')   
                      ->select(
                            'pd.country',
                            DB::raw('count(pd.property_id)')
                        )
                      ->groupBy('pd.city')
                      ->distinct('pd.city');
        if($city){

            $citiesQuery->whereRaw("pd.city = '". $city ."'");
        }  

        $cities     = $citiesQuery->whereRaw('pd.status = "active"')
                        ->whereRaw('pd.verified = "yes"')
                        ->whereRaw('pd.city !=""')
                        ->whereRaw('u.status = "active"')
                        ->orderByRaw('count(pd.property_id) DESC')
                        ->orderBy('pd.city', 'asc')                         
                        ->first();

        //$cities = DB::select("select distinct pd.city, COUNT(property_id) from property_details as pd left join users as u on u.id=pd.user_id where pd.city != '' and pd.status ='active' and pd.country='".$country."' and u.status='active' group by pd.city order by count(property_id) DESC, pd.city asc limit 0,10");

          
        if($cities){

            return Response::json(array('success'=>'1', 'country'=>$cities));

        }else{
            
            return Response::json(array('success'=>'0', 'countries'=>'No cities are there!'));                                               
        }
    }

    public function getPropertyAllCityByCountriesList(Request $request){
 	

    	$country = $request['country']!=''?$request['country']:'';

    	$citiesQuery = DB::table('property_details as pd')
    				  ->leftJoin('users as u', 'u.id', '=', 'pd.user_id')	
                      ->select(
                            DB::raw('CONCAT(pd.city, ", ", pd.country) AS destination'),
                      		'pd.city',
                            'pd.country',
                      		DB::raw('count(pd.property_id)')
                      	)
                      ->groupBy('pd.city')
                      ->distinct('pd.city');
		if($country){

			$citiesQuery->whereRaw("pd.country = '". $country ."'");
		}  

        $cities 	= $citiesQuery->whereRaw('pd.status = "active"')
                    	->whereRaw('pd.verified = "yes"')
                    	->whereRaw('pd.city !=""')
                    	->whereRaw('u.status = "active"')
                    	->orderByRaw('count(pd.property_id) DESC')
                    	->orderBy('pd.city', 'asc')
                    	->get();

    	//$cities = DB::select("select distinct pd.city, COUNT(property_id) from property_details as pd left join users as u on u.id=pd.user_id where pd.city != '' and pd.status ='active' and pd.country='".$country."' and u.status='active' group by pd.city order by count(property_id) DESC, pd.city asc");

          
        if($cities){

            return Response::json(array('success'=>'1', 'cities'=>$cities));

        }else{
            
            return Response::json(array('success'=>'0', 'countries'=>'No cities are there!'));                                               
        }
    }

    public function getCheckHolidayMakerDepartureTime(){

        $data = DB::table('booknow_property_details as pb')
            ->select('pb.*',
                     'pb.id as booking_id',
                     'pd.description as property_description',
                     'pd.property_image',
                     'pb.guest_limit as guest',
                     DB::raw('DATE_FORMAT(pb.arrival_time, "%d %b %Y") as barrival_time'),
                     DB::raw('DATE_FORMAT(pb.departure_time, "%d %b %Y") as bdeparture_time'),
                     'pb.guest_limit as bguest', 'pd.*', 
                     DB::raw('CONCAT(u.first_name, " ", u.surname) AS name'),
                     DB::raw('CONCAT(pb.first_name, " ", pb.surname) AS user_name'), 
                     'u.email as owner_mail'
                    )
            ->leftJoin('property_details as pd', 'pd.property_id','=','pb.property_id')
            ->leftJoin('users as u', 'u.id', '=', 'pb.owner_id')
            ->whereRaw('DATE(pb.departure_time) = DATE(NOW() - INTERVAL 1 DAY)')
            ->whereNull('review_link_status')
            ->where('payment_status', 'yes')
            ->get();        
        //print_r($data); die();
        if(count($data)>0){

            foreach ($data as $k => $v) {
                $booking = $v;

                $mail   =  Mail::send('emails.property-booking-client-testimonial', ['booking'=>$booking], function ($m) use ($booking) {

                    $m->from($this->from_email, 'Direct Owners');

                    $m->to($booking['email'])->subject('Feedback Request from Direct-Owners');
                });
                
                if($mail){

                    $update = DB::table('booknow_property_details')->where('id', $v['booking_id'])->update(array('review_link_status'=>1));
                }
                echo $mail;

                echo $booking['email'].'<br>';
            }
        }
    }


    public function getReviewPropertyDetailsById(Request $request){

        $prop_id = $request['property_id'];

        $data = DB::table('property_details')
                ->select(
                    'property_id',
                    'property_title',
                    'property_image'
                )
                ->where('property_id', $prop_id)
                ->first();

        $chk_img = $_SERVER['DOCUMENT_ROOT']."/uploads/property_images/".$data['property_id']."/".$data['property_image'];
        
        if(file_exists($chk_img)){
            
          $img = "https://direct-owners.com/uploads/property_images/".$data['property_id']."/".$data['property_image'];
        }else{
          
          $img = "https://direct-owners.com/uploads/property_images/default.jpg";
        }

        $prop_title = ucwords($data['property_title']);    
        if($data){

            return Response::json(array('success'=>1, 'prop_title'=>$prop_title, 'img_src'=>$img, 'data'=>$data));
        }else{

            return Response::json(array('success'=>0, 'data'=>'No Data Found'));
        }                
    }

    public static function getAllOwnerPreblockPropertyDetailsById(Request $request){

        $uid = $request['owner_id'];
        $pid = $request['property_id'];

        $data = DB::table('property_preblock_details as ppd')
                ->select(
                    'ppd.*', 
                    DB::raw('DATE_FORMAT(ppd.start_date, "%b %d, %Y") as start_date'), 
                    DB::raw('DATE_FORMAT(ppd.end_date, "%b %d, %Y") as end_date'),
                    'pd.property_title'
                )
                ->join('property_details as pd', 'pd.property_id', '=', 'ppd.property_id')
                ->where('pd.user_id', $uid)
                ->where('pd.property_id', $pid)
                ->orderBy('created_at', 'desc')
                ->get();

        if($data){

            return Response::json(array('success'=>'1', 'message'=>'Reserved dates details', 'details'=>$data));
        }else{

            return Response::json(array('success'=>'0', 'message'=>'No details found'));
        }
    }

    public function getUpdateAccessToken(Request $request){

        $data                = $request->all();
        Log::info(print_r($data, true));
        $basic_currency      = isset($data['basic_currency'])?strtoupper($data['basic_currency']):'';
        $user_id             = isset($data['user_id'])?$data['user_id']:'';
        $tmt_api_token       = isset($data['tmt_api_token'])?$data['tmt_api_token']:'';
        $pemail              = isset($data['pemail'])?$data['pemail']:'';

        if($basic_currency || $tmt_api_token || $user_id || $pemail){
                                    
            $array = array(
                    'basic_currency'        => $basic_currency, 
                    'tmt_api_token'         => $tmt_api_token,
                    'paypal_email'          => $pemail
                );
            $update = DB::table('users')->where('id', $user_id)->update($array);
            $user_details = User::find($user_id);
            if($update){

                return Response::json(array('success'=>'1', 'message'=>'Details updated successfully', 'details'=>$user_details));
            }else{
                return Response::json(array('success'=>'0', 'message'=>'Details were not updated, please check again'));
            }
        }else{
            return Response::json(array('success'=>'0', 'message'=>'Please fill the inputs'));
        }
    }

    public function testLink(Request $request){

        
    }
    
    public function addPropertyStepOne(Request $request){


        //$res = $this->checkVirusInFile($request->all());
        //echo "<pre>"; print_r($request->file()); print_r($request->all()); exit;

        //$all_files = $request->file();
        if($request->hasfile('image_name')){
            $file_ext = array('gif','png','jpg','jpeg');
        foreach ($request->file('image_name') as $key => $value) {
            if($value->getClientSize() > 3000000){
                return Response::json(["success"=>0,"message"=>"Request image ".$value->getClientOriginalName()." size is more then 3 MB."]);
            }else if(!in_array($value->getClientOriginalExtension(),$file_ext)){
                return Response::json(["success"=>0,"message"=>"Request file ".$value->getClientOriginalName().".".$value->getClientOriginalExtension()." is not a image."]);
            }
        }
        }

        //echo "<pre>"; print_r($request->all()); exit;

        
        if(!empty($request->property_id)){

            $property_update = DB::table("property_details")->where("property_id",$request->property_id)->update([
                "property_title"    => $request->property_title,
                "description"       => htmlspecialchars($request->description, ENT_QUOTES),
                "space_type"        => $request->space_type,
                "guest_limit"       => $request->guest_limit,
                "single_room"       => $request->single_room,
                "double_room"       => $request->double_room,
                "twin_room"         => $request->twin_room,
                "other_room"        => $request->other_room,
                "bathroom"          => $request->bathroom,
                "user_id"           => $request->user_id
            ]);
            $property = $request->property_id;

        }else{

            $property = DB::table("property_details")->insertGetId([
                "property_title"    => $request->property_title,
                "description"       => htmlspecialchars($request->description, ENT_QUOTES),
                "space_type"        => $request->space_type,
                "guest_limit"       => $request->guest_limit,
                "single_room"       => $request->single_room,
                "double_room"       => $request->double_room,
                "twin_room"         => $request->twin_room,
                "other_room"        => $request->other_room,
                "bathroom"          => $request->bathroom,
                "user_id"           => $request->user_id
            ]);

        }

        if($property){

        if(!empty($request->file('main_image_name'))){

            $files           = $request->file('main_image_name');   
            $local_directory = public_path().'/uploads/property_images/'.$property.'/'; 
            $directory       = 'uploads/property_images/'.$property;
            if (!file_exists($local_directory)) {
                mkdir($local_directory, 0777, true);
            }


            $filename        = 'main_image.'.$files->getClientOriginalExtension(); 
            $local_img       = $files->move($local_directory,$filename);

            $image           = Image::make($local_img);
            $resize_image    = $image->fit(640,427)->stream();
            //Move the uploaded file to temp directory
            $upload_success  = Storage::disk('s3')->put($directory.'/'.$filename, $resize_image->__toString(), 'public');
           
            if($upload_success){
                unlink($local_directory.'/'.$filename);
            }

            

            //PropertyDetails::compressImage($img_path, $img_path, 70);
            DB::table("property_details")->where("property_id",$property)->update(["property_image"=>$filename]);
        }  

        if($request->hasfile('image_name')){ 
            $find_img = DB::table("property_gallery")->where("property_id",$property)->get();
            //echo "<pre>"; print_r($find_img); exit;
            if(count($find_img)>0){
                foreach ($find_img as $key => $value) {
                    $fname = isset($value["image_name"])?$value["image_name"]:$value->image_name;
                    unlink(public_path().'/uploads/property_images/'.$property.'/'.$fname);
                }
                DB::table("property_gallery")->where("property_id",$property)->delete();
            }
            $images= PropertyGallery::savePropertyImages($request, $property);
        }    

            return Response::json(["success"=>1,"message"=>"Property Added.","property_id"=>$property]);
        }else{
            return Response::json(["success"=>0,"message"=>"Fail To Add Property"]);
        }


    }

    public function addPropertyStepTwo(Request $request){
        //echo "<pre>"; print_r($request->all()); exit;
        if(!empty($request->property_id)){

            $update = DB::table("property_details")->where("property_id",$request->property_id)->update($request->all());

            return Response::json(["success"=>1,"message"=>"Property location details Added.","property_id"=>$request->property_id]);

        }else{
            return Response::json(["success"=>0,"message"=>"Fail To Add Property","message1"=>"property id is missing"]);
        }

    }

    public function addPropertyStepThree(Request $request){
        //echo "<pre>"; print_r($request->all()); exit;
        if(!empty($request->property_id)){
            $find_data = DB::table("property_amenity")->where("property_id",$request->property_id)->select("property_amenity_id")->first();
            if(empty($find_data)){
                $insert = DB::table("property_amenity")->insertGetId($request->all());
            }else{
                $update = DB::table("property_amenity")->where("property_id",$request->property_id)->update($request->all());
            }
            return Response::json(["success"=>1,"message"=>"Property amenity details Added.","property_id"=>$request->property_id]);
        }else{
            return Response::json(["success"=>0,"message"=>"Fail To Add Property","message1"=>"property id is missing"]);
        }
    }

    public function addPropertyStepFour(Request $request){
        //echo "<pre>"; print_r($request->all()); exit;
        //echo "<pre>"; print_r(json_decode($request->property_ids)); exit;

        if(!empty($request->property_id)){

            $propertyIDS = json_decode($request->property_ids);

            $property_update = DB::table("property_details")->where("property_id",$request->property_id)->update(["standard_rate_per_day"=>$request->standard_rate_per_day,"standard_rate_per_week"=>$request->standard_rate_per_week,"security_deposit_amount"=>$request->security_deposit_amount,"minimum_stay"=>$request->minimum_stay]);

            if(!empty($request->property_rate) && isset($request->property_rate) && count($request->property_rate["start_date"])>0){
                
                foreach ($request->property_rate["start_date"] as $key => $value) {

                    if(!empty($value) && !empty($request->property_rate["end_date"][$key]) && !empty($request->property_rate["specific_rate_name"][$key]) && !empty($request->property_rate["rate_per_day"][$key]) && !empty($request->property_rate["rate_per_week"][$key])){

                        if(!empty($propertyIDS) && !empty($propertyIDS[$key])){
                            $prid = DB::table("property_rate")->where("property_rate_id",$propertyIDS[$key])->update(["rate_name"=>$request->property_rate["specific_rate_name"][$key],"start_date"=>$request->property_rate["start_date"][$key],"end_date"=>$request->property_rate["end_date"][$key],"rate_per_day"=>$request->property_rate["rate_per_day"][$key],"rate_per_week"=>$request->property_rate["rate_per_week"][$key],"minimum_stay"=>$request->property_rate["minimum_stay"][$key],"property_id"=>$request->property_id]);

                            $property_rates_id[$key] = $propertyIDS[$key];
                        }else{
                            $prid = DB::table("property_rate")->insertGetId(["rate_name"=>$request->property_rate["specific_rate_name"][$key],"start_date"=>$request->property_rate["start_date"][$key],"end_date"=>$request->property_rate["end_date"][$key],"rate_per_day"=>$request->property_rate["rate_per_day"][$key],"rate_per_week"=>$request->property_rate["rate_per_week"][$key],"minimum_stay"=>$request->property_rate["minimum_stay"][$key],"property_id"=>$request->property_id]);

                            $property_rates_id[$key] = $prid;
                        }      

                    }

                }

            }

            if(!isset($property_rates_id)){
                $pri = array();
            }else{
                $pri=json_encode($property_rates_id);
            }
            return Response::json(["success"=>1,"message"=>"Property rates details Added.","property_rates_id"=>$pri]);
        }else{
            return Response::json(["success"=>0,"message"=>"Fail To Add Property","message1"=>"property id is missing"]);
        }
    }

    public function addPropertyStepFive(Request $request){
        $property_id = $request->property_id;
        if(!empty($property_id)){
            DB::table("property_details")->where("property_id",$property_id)->update(["status"=>"inactive"]);
            return Response::json(["success"=>1,"message"=>"Property details published.","property_id"=>$property_id]);
        }else{
            return Response::json(["success"=>0,"message"=>"Fail To Add Property","message1"=>"property id is missing"]);
        }
    }

    public function getScantheFileForVirus(Request $request){
    
    //echo "<pre>"; print_r($request->all()); exit;
        
        $file_to_scan = $request->file('image_file');
        
        $config = SwaggerConfiguration::getDefaultConfiguration()->setApiKey('Apikey', 'd5089e9c-96b1-499a-8f95-b80a3d187b17');
        
        // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
        // $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Apikey', 'Bearer');

        $apiInstance = new SwaggerScanApi(
            // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
            // This is optional, `GuzzleHttp\Client` will be used as default.
            new Client(),
            $config
        );
        $image_file = $file_to_scan; // \SplFileObject | Image file to perform OCR on.  Common file formats such as PNG, JPEG are supported.
        try {
            $result = $apiInstance->scanFile($image_file);            
            
            Log::info(print_r($result, true));
            if($result['clean_result']==1){

               return Response::json(['success'=>1, 'message'=>'File scanned successfully, no virus found']);
            }else{
                return Response::json(['success'=>0,'message'=>'File is not safe to upload. please try another!']);
            }
        } catch (Exception $e) {

            return Response::json(['success'=>0,'message'=>$e->getMessage()]);
            
        }        

    }

    public function getScanMultipleFilesForVirus(Request $request){
        

        Log::info(print_r($request->all(), true));
        if($request->hasfile('image_name')){
            $files          = $request->file('image_name');    

            $rejected_index = array();
            $success_index  = array();
            $rejected_files = array();
            $success_files  = array();
            $count = 0;
            foreach($files as $k=>$file){
                $file_to_scan = $file;
                
                $config = SwaggerConfiguration::getDefaultConfiguration()->setApiKey('Apikey', 'd5089e9c-96b1-499a-8f95-b80a3d187b17');
                
                // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
                // $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Apikey', 'Bearer');

                $apiInstance = new SwaggerScanApi(
                    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
                    // This is optional, `GuzzleHttp\Client` will be used as default.
                    new Client(),
                    $config
                );
                $image_file = $file_to_scan; // \SplFileObject | Image file to perform OCR on.  Common file formats such as PNG, JPEG are supported.
                try {
                    $result = $apiInstance->scanFile($image_file);            
                    
                    //Log::info(print_r($result, true));
                    if($result['clean_result']==1){

                        array_push($success_index, $k);
                        array_push($success_files, $file);
                    }else{
                        array_push($rejected_index, $k);
                        array_push($rejected_files, $file);
                    }
                } catch (Exception $e) {

                    array_push($rejected_files, $k);
                    
                }

                $count++;
            }

            if(count($rejected_index)){

                return Response::json(['success'=>1, 'message'=>'We rejected some files which are virus effected', 'success_files'=>$success_files, 'rejected_files'=>$rejected_files, 'rejected_count'=>$rejected_index, 'cleared_count'=>$success_index]);    
            }else{

                if(count($success_files)>1){
                    $message = 'All files are scanned successfully, no virus found';
                }else{
                    $message = 'File scanned successfully, no virus found';
                }
                return Response::json(['success'=>1, 'message'=>$message, 'success_files'=>$success_files, 'rejected_files'=>$rejected_files, 'rejected_count'=>$rejected_index, 'cleared_count'=>$success_index]);
            }
        }    
    }

    public function getCurrencyRate(Request $request){

        Log::info(print_r($request->all(), true));
        $currency_name = isset($request['currency_name'])?strtoupper($request['currency_name']):'';

        $currency_rate = $currency_name=='EUR'?1:PropertyDetails::convertCurrency($currency_name); 

        if($currency_rate){

            return Response::json(["success"=>1,"currency_rate"=>$currency_rate]);
        }else{

            return Response::json(["success"=>0,"currency_rate"=>$currency_rate]);
        }
    }    
}
