<?php

namespace App\Http\Controllers\Api\Properties;

use Illuminate\Support\Facades\Input;

use App\Http\Controllers\Controller;

use Tymon\JWTAuth\Facades\JWTAuth;

use Illuminate\Http\Request;

use Validator;

use Response;

use App\User;

use Hash;

use Mail;

use DB;

use Log;
use Config;
class UserController extends Controller
{
	
	public function __construct(){
      
       $this->middleware('jwt.auth', ['except' => ['userSignUp', 'userLogin', 'getUpdateUserDetails', 'getUserDetailsById', 'changePassword', 'getUsersList', 'getDeleteUserDetails', 'updateUserEmailVerificationStatus', 'sendUserOTP', 'checkUserOTP', 'getRequestForgotPassword', 'getResetOwnerPassword', 'getCheckOwnerSubscriptionPeriod', 'getCheckTestCronJob']]);
       $this->from_email             = Config::get('app.email_from_address');
       $this->_s3_path               = Config::get('filesystems.s3_path');
    }

	public function userSignUp(){
//print_r(Input::all());die();
		$signupRules = array(
			'title' 			=> 'required',		
			'first_name' 		=> 'required',
			'surname' 			=> 'required',
			'email' 			=> 'required|email|unique:users,email',
			'password' 			=>array(
									'required',
			                        'min:8',
			                        'regex:/^(?=.*[A-Z])(?=.*\d)(?=.*(_|[^\w])).+$/'
			                    ),
			'confirm_password'	=>'required|same:password',
			'phone' 			=> 'required|phone_number',
		);

		Validator::extend('phone_number', function($attribute, $value, $parameters, $validator) {
        return preg_match('%^(?:(?:\(?(?:00|\+)([1-4]\d\d|[1-9]\d?)\)?)?[\-\.\ \\\/]?)?((?:\(?\d{1,}\)?[\-\.\ \\\/]?){0,})(?:[\-\.\ \\\/]?(?:#|ext\.?|extension|x)[\-\.\ \\\/]?(\d+))?$%i', $value) && strlen($value) >= 10;
		    });

		Validator::replacer('phone_number', function($message, $attribute, $rule, $parameters) {
		        return str_replace(':attribute',$attribute, 'Entered invalid phone number');
		    });

		$input = Input::all();
		
		$validator = Validator::make(
            Input::all(), $signupRules
        );

        if($validator->fails()){

            return Response::json(array('success'=>0, 'message'=>$validator->getMessageBag()->first()), 400);
        }else{      
                
			$user = User::signup($input);

			return $user;

	    }
	}

	public function userLogin(){ 
		
		$input = Input::all();

		$loginRules = array(
			'email' => 'required',
			'password' => 'required'
		);

		$validator = Validator::make(
			Input::all(), $loginRules
		);

		if($validator->fails()){
			return Response::json(array('success'=>0, 'message'=>$validator->getMessageBag()->first()), 400);
		}
		else{

			$credentials = Input::only('email', 'password');	
		
			$userDetails = User::login($input);

			
			try {
	            // verify the credentials and create a token for the user
	            if($userDetails!='no'){
		            if (! $token = JWTAuth::attempt($credentials)) {

		            	return Response::json(array('success'=>0, 'message'=>'Entered invalid credentials'), 400);
		                //return response()->json(['error' => 'invalid_credentials'], 401);
		            }
	        	}else{

	        		return Response::json(array('success'=>0, 'message'=>'User not verified yet!'), 400);
	        	}
	        } catch (JWTException $e) {
	            // something went wrong
	            return response()->json(['error' => 'could_not_create_token'], 500);
	        }

	        // if no errors are encountered we can return a JWT
	        return response()->json(compact('token', 'userDetails'));
		}
	}

	public function sendActivationMail($user_data){

		$mail  	= Mail::send('emails.owner-activate', ['user_details'=>$user_data], function ($m) use ($user_data) {

                                $m->from($this->from_email, 'Direct Owners');

                                $m->to($user_data['email'])->subject('Account Activated – Direct-Owners');
                               });
		//Log::info(print_r($mail.' inactive mail', true));
		//Log::info(print_r($user_data, true));
	}
	
	public function sendDeactivationMail($user_data){

		$mail  	= Mail::send('emails.deactivate', ['user_details'=>$user_data], function ($m) use ($user_data) {

                                $m->from($this->from_email, 'Direct Owners');

                                $m->to($user_data['email'])->subject('Account Inactivated – Direct-Owners');
                               });
		//Log::info(print_r($mail.' inactive mail', true));
		//Log::info(print_r($user_data, true));
	}

	public function getDeleteUserDetails(Request $request){
		
		$user_id     = isset($request['user_id'])?$request['user_id']:'';
		$user_status = isset($request['user_status'])?$request['user_status']:'';
		
		

	    //die();
        //$property_id = User::getPropertyIdByOwnerId($id);        
		if($user_id && $user_status){
			
			if($user_status=='active'){
				$get_prop_status = DB::table('property_details')->select('property_id', 'status')->where('user_id', $user_id)->get();

				if($get_prop_status){
					$result = array();
					foreach($get_prop_status as $ps){
						Log::info(print_r($ps, true));
						$update_prop = DB::table('property_details')->where('property_id', $ps['property_id'])->update(array('before_owner_inactive'=>$ps['status']));
					}
				}
				$status = 'inactive';
			}else{
				$status = 'active';
				$get_prop_status = DB::table('property_details')->select('property_id', 'before_owner_inactive')->where('user_id', $user_id)->get();

				if($get_prop_status){
					$result = array();
					foreach($get_prop_status as $ps){
						Log::info(print_r($ps, true));
						$update_prop = DB::table('property_details')->where('property_id', $ps['property_id'])->update(array('status'=>$ps['before_owner_inactive']));
					}
				}
			}
			$update = array('status'=>$status);			
	        $data = DB::table('users')->where('id', $user_id)->update($update);
	        //$property_enquiry    = DB::table('property_enquiry')->where('owner_id', $id)->delete();
				//$data = '';
	        if($data){

	        	$user_data = DB::table('users')->select('email', 'id', DB::raw('CONCAT(first_name, " ", surname) AS name'))->where('id', $user_id)->first();
	        	if($status=='inactive'){
	        		$inactive_owner_props = DB::table('property_details')->where('user_id', $user_id)->update($update);	
	        		
					//Log::info(print_r($user_data, true));
				    $this->sendDeactivationMail($user_data);
	        		Log::info(print_r($inactive_owner_props.' inactive_owner_props', true));
	        	}else if($status=='active'){

	        		
					//Log::info(print_r($user_data, true));
				    $this->sendActivationMail($user_data);
	        	}
	            
	        }        

	        if($data){

	            return Response::json(array('success'=>1, 'user_details'=>$data), 200);
	        }else{

	            return Response::json(array('success'=>0, 'message'=>'No user found, Please try again'), 200);
	        }
		}else{
			
            return Response::json(array('success'=>0, 'message'=>'No user found, Please try again'), 200);
        }        			
	}

	public function getUpdateUserDetails(Request $request){
		
		$request = $request->all();	
		
		$updateRules = array(
			'user_id' => 'required',
			'email' =>'unique:users,email,'.$request['user_id']
		);
		
		$validator = Validator::make(

			$request, $updateRules

		);

		if($validator->fails()){

			return Response::json(array('success'=>0, 'message'=>$validator->getMessageBag()->first()), 400);
		}else{

			$userDetails = User::getUpdateUserDetails($request);

			return $userDetails;

		}

	}

	public function getUserDetailsById(Request $request){
		$request = $request->all();

		$getUserDetailsRules = array(
			'user_id' => 'required',
		);

		$validator = Validator::make(
			Input::all(), $getUserDetailsRules
		);

		if($validator->fails()){

			return Response::json(array('success'=>0, 'message'=>$validator->getMessageBag()->first()), 400);
		}else{

			$userDetails = User::getUserDetailsById($request['user_id']);

			if($userDetails){

				return Response::json(array('success'=>1, 'message'=>'Profile update successfully', '_s3_path'=>$this->_s3_path, 'user_details'=>$userDetails), 200);

			}else{

				return Response::json(array('success'=>0, 'message'=>'No user found, Please try again'), 400);
			}
		}
	}

	public function changePassword(Request $request){

		$request = $request->all();

		$resetPasswordRules = array(
			'user_id'=>'required',
			'old_password'=>'required',
			'new_password'=>'required|min:6',
			'confirm_password'=>'required|same:new_password'
		);

		$validator = Validator::make(

			$request, $resetPasswordRules
		);
		if($validator->fails()){

			return Response::json(array('success'=>0, 'message'=>$validator->getMessageBag()->first()), 400);
		}else{

			$password = User::changeUserPassword($request);

			return $password;
		}
	}

	public function getUsersList(){

		return User::getAllUsersList();
	}

	public function updateUserEmailVerificationStatus($status, $uid){

		$user = User::updateUserEmailVerificationStatus($status, $uid);

		return $user;
	}

	public function sendUserOTP($mobile, $uid){

		$user = User::sendUserOTP($mobile, $uid);
		return $user;
	}

	public function checkUserOTP($otp, $uid){

		$user = User::checkUserOTP($otp, $uid);

		return $user;
	}

	public function getRequestForgotPassword(Request $request){

		$email  = $request['email'];

		$data 	= DB::table('users')
					->select(
						'id',
						'email',
						DB::raw('CONCAT(first_name, " ", surname) AS name')					
					)
					->where('email', $email)
					->first();
		if($data){

			$send_email = $this->getSendPasswordDetailsToMail($data);

			if($send_email){

				return Response::json(array('success'=>1, 'message'=>'Please check your mail to reset your password'), 200);
			}
		}else{

			return Response::json(array('success'=>0, 'message'=>'No user found with this email id'), 200);	
		}
	}

	public function getSendPasswordDetailsToMail($data){

		$mail  	=  Mail::send('emails.forgot-password', 
                    ['user'   => $data], function ($m) use ($data) {

                        $m->from($this->from_email, 'Direct Owners');

                        $m->to($data['email'])->subject('Password Reset Request - Direct-Owners');
                    });

		return $mail;
	}

	public function getResetOwnerPassword(Request $request){

		$password_rules = array(
			'new_password'=>array('required',
                          'min:8',
                          'regex:/^(?=.*[A-Z])(?=.*\d)(?=.*(_|[^\w])).+$/'
                         ),
			'confirm_password'=>'required|same:new_password',
		);

		$message = array(
                     'new_password.regex' 	   => 'Required minimum 8 characters, at least 1 Uppercase, 1 Numeric and 1 Special Character'  
                   );
		
		
		$validator = Validator::make(
            Input::all(), $password_rules, $message
        );

        if($validator->fails()){

            return Response::json(array('success'=>0, 'message'=>$validator->getMessageBag()->first()), 200);
        }else{

        	$data = DB::table('users')
        			->where('id', $request['user_id'])
        			->update(array(
                        'password' => Hash::make($request['new_password'])
                    ));

			if($data){

				return Response::json(array('success'=>1, 'message'=>'Password has been changed successfully, please now login to your account'), 200);
			}else{

				return Response::json(array('success'=>0, 'message'=>'Something went wrong please try again!'), 200);
			}
        }
	}


	public function getCheckOwnerSubscriptionPeriod(Request $request){

		$data = DB::table('users as u')
                ->select('u.id','u.expiry_date', 'u.status', 'in.status as pay_status', 'in.expiry_date as pay_exp_date')
                ->leftJoin('invoices as in', 'in.user_id', '=', 'u.id')
                ->where('in.status', 'pending')                
                ->orderBy('in.id', 'desc')                
                ->get();
        
        foreach ($data as $d) {
        	
        	$exp_date = date('Y-m-d', strtotime($d['expiry_date']));
	        $status   = $d['pay_status'];
	        $chk_date = date('Y-m-d');        
	        $datediff = strtotime($exp_date) - strtotime($chk_date);
	        $daysLeft = $datediff/(60 * 60 * 24)+1;   	        
	        echo '<pre>'.$exp_date.'__'.$chk_date.'__'.$d['id'].'__'.$daysLeft.'<br>';

	        if($exp_date >= $chk_date && $status=='pending'){           
	             
	            $renewalAccMail = $this->userAccountRenewalNotification($d['id'], $daysLeft, $exp_date);                 
	        }else{
	        	if($daysLeft=='-13'){

	        		$renewalAccMail = $this->userAccountRenewalNotification($d['id'], $daysLeft, $exp_date);

		            $update = DB::table('users')
		                      ->where('id', $d['id'])
		                      ->update(array(
		                        'status'=>'inactive'
		                      )); 
		            echo $update;
	        	}	            
	        }
        }         
	}

	public function userAccountRenewalNotification($uid, $nofdays, $exp){
         
        $date = date('d-m-Y', strtotime($exp));
        

        //echo '<pre>'.$uid.'__'.$nofdays.'__'.$exp;
        switch ($nofdays) {
            case '30':
                    $msg  = 'Your account is going to be expire with in '.$nofdays.' days i.e('.$date.'), Please renew your account to avoid any inconvenience.'; 
                    $mail = $this->sendRenewalAccountMail($uid, $msg);                           
                break;	

            case '14':
                    $msg  = 'Your account is going to be expire with in 14 days i.e('.$date.'), Please renew your account to avoid any inconvenience.'; 
                    $mail = $this->sendRenewalAccountMail($uid, $msg);                           
                break;

            case '7':
                    $msg = 'Your account is going to be expire with in 7 days i.e('.$date.'), Please renew your account to avoid any inconvenience.';
                    $mail = $this->sendRenewalAccountMail($uid, $msg);
                break;

            case '6' :
                    $msg = 'Your account is going to be expire with in 6 days i.e('.$date.'), Please renew your account to avoid any inconvenience.';
                    $mail = $this->sendRenewalAccountMail($uid, $msg);
                break;

            case '5' :
                    $msg = 'Your account is going to be expire with in 5 days i.e('.$date.'), Please renew your account to avoid any inconvenience.';
                    $mail = $this->sendRenewalAccountMail($uid, $msg);
                break;

			case '4' :
                    $msg = 'Your account is going to be expire with in 4 days i.e('.$date.'), Please renew your account to avoid any inconvenience.';
                    $mail = $this->sendRenewalAccountMail($uid, $msg);
                break;

            case '3' :
                    $msg = 'Your account is going to be expire with in 3 days i.e('.$date.'), Please renew your account to avoid any inconvenience.';
                    $mail = $this->sendRenewalAccountMail($uid, $msg);
                break;

            case '2' :
                    $msg = 'Your account is going to be expire with in 2 days i.e('.$date.'), Please renew your account to avoid any inconvenience.';
                    $mail = $this->sendRenewalAccountMail($uid, $msg);
                break;
                
            case '1' :
                    $msg = 'Your account is going to be expire today i.e('.$date.'), Please renew your account to avoid any inconvenience.';
                    $mail = $this->sendRenewalAccountMail($uid, $msg);
                break;
              

            case '-13' :
                    $msg = 'Your account was expired on ('.$date.'), please renew your account to avoid any inconvenience.';
                    $mail = $this->sendRenewalAccountMail($uid, $msg);
                break;              
            
            default:
                
                break;
        }            
    }

    public function sendRenewalAccountMail($uid, $msg){

        $userData   = DB::table('users as u')
                        ->select(DB::raw('CONCAT(u.first_name, " ", u.surname) AS name'),'u.email')
                        ->where('u.id', $uid)                    
                        ->first();
        $name       = $userData['name'];                
        $email      = $userData['email'];                
        $mail       =  Mail::send('emails.account-renewal-alert', 
                               ['name'   => $name,
                                'msg'    => $msg,
                                'email'  => $email
                               ], function ($m) use ($email) {

                               $m->from($this->from_email, 'Direct Owners');

                               $m->to($email)->subject('Account renewal alert from Direct Owners');
                        });
        $mail;
    }

    public function getCheckTestCronJob(){
    	$email 		= 'kavitha@travash.com';
    	$mail       =  Mail::send('emails.account-renewal-alert', 
                               ['name'   => 'Kavitha',
                                'msg'    => 'Test Cron',
                                'email'  => 'kavitha@travash.com'
                               ], function ($m) use ($email) {

                               $m->from($this->from_email, 'Direct Owners');

                               $m->to($email)->subject('Test Cron Job');
                        });
        $mail;
    }
}
