<?php

namespace App\Http\Controllers\SuperAdmin;

use Illuminate\Support\Facades\Input;

use App\Http\Controllers\Controller;

use Illuminate\Http\Request;

use App\Http\Requests;

use App\FlashSales;

use Validator;

use Response;

use DB;

class FlashSalesController extends Controller
{
    
    public function getDisplayFlashSales()
    {
    	return view('super_admin.flash-sales');
    }

    public function getDisplayAddFlashSalePage($action)
    {	
    	$countries 	= DB::table('property_details')
	    				->select('country')
	    				->where('verified', 'yes')
	    				->where('status', 'active')
	    				->groupBy('country')
	    				->orderBy('country', 'asc')
	    				->get();
		$cities 	= DB::table('city')			    		
							->select('*')
							->orderBy('city', 'asc')
							->get();

    	if($action=='add'){
			
    		return view('super_admin.add-flash-sale', compact('cities', 'countries'));	

    	}else{

    		$input = Input::all();

    		$data = DB::table('flash_sales')
    				   ->select('*')
    				   ->where('id', $input['id'])
    				   ->first();

    		return view('super_admin.add-flash-sale', compact('cities', 'countries', 'data'));	
    	}    	
    }

    public function getCitiesListByCountry(Request $request){

        $country = $request['country_id'];

        $cities = DB::table('property_details')
                ->select('city')
                ->distinct('city')
                ->where('country', $country)
                ->orderBy('city', 'asc')
                ->get();

        if($cities){

            return Response(array('success'=>1, 'message'=>'Cities found', 'data' =>$cities), 200);
        }else{

            return Response(array('success'=>0, 'message'=>'Cities not found'), 200);
        }         
    }

    public function generateUniqueCoupon() {


        $string = substr(str_shuffle(str_repeat("ABCDEFGHIJKLMNOPQRSTUVWXYZ", 5)), 0, 1);
        $number = substr(str_shuffle(str_repeat("0123456789", 2)), 0, 3);
        $coupon = 'DO'.$number.''.$string;
        if ($this->checkCouponExistsOrNot($coupon)) {
            return $this->generateUniqueCoupon();
        }

        return $coupon;
    }

    public function checkCouponExistsOrNot($coupon){

        $data = DB::table('flash_sales')
                ->where('coupon_code', $coupon)
                ->first();
        return $data;
    }

    public function getSaveFlashSaleDetails(Request $request){

    	$request = $request->all();     
        //print_r($request)   		; exit;
		$discount_amount = '';
        if($request['discount_type']=='flat'){

            $discount_amount = 'discount_flat_amount';

        }else{

            $discount_amount = 'discount_perc_amount';
        }

		$addRules = array(
						'coupon_name' 		=>'required',
						'minimum_value'		=>'required|regex:/[0-9]/',
						'discount_type'		=>'required',
						$discount_amount	=>'required|regex:/[0-9]/',
						'from_date'         =>'date|required',
                        'to_date'           =>'date|required|date_custom_validation:from_date,to_date|before_or_equal:from_date',
					);


        if(isset($request['flash_sale_id']) && $request['flash_sale_id']) {

            Validator::extend('date_custom_validation', function ($attribute, $value, $parameters, $validator) {
                  $inputs = $validator->getData();
                    
                  $data   = DB::table('flash_sales')
                            ->select('*')  
                            ->whereRaw('to_date >= "'.$inputs['from_date'].'"')
                            ->whereRaw('from_date <= "'.$inputs['to_date'].'"')
                            ->whereRaw('id !='.$inputs['flash_sale_id'])                    
                            ->get();
                    
                  if(count($data)){
                    return false;
                  } else{
                    return true;
                  } 
                  
            });

        }else{

            Validator::extend('date_custom_validation', function ($attribute, $value, $parameters, $validator) {
                  $inputs = $validator->getData();
                    
                  $data   = DB::table('flash_sales')
                            ->select('*')  
                            ->whereRaw('to_date >= "'.$inputs['from_date'].'"')
                            ->whereRaw('from_date <= "'.$inputs['to_date'].'"')
                            ->get();
                    
                  if(count($data)){
                    return false;
                  } else{
                    return true;
                  } 
                  
            });   
        }
        

        Validator::extend('before_or_equal', function($attribute, $value, $parameters, $validator) {
            return strtotime($validator->getData()[$parameters[0]]) <= strtotime($value);
        });

        $message = array(
                     'to_date.before_or_equal' => 'From date should not be greater than To date',
                     'date_custom_validation'  => 'Some of the dates has flash sale already , please try another dates'  
                   );
				
		$validator = Validator::make(

			$request, $addRules, $message

		);

		if($validator->fails()){

			return Response::json(array('success'=>0, 'message'=>$validator->getMessageBag()->first()), 200);
		}else{

			if(isset($request['flash_sale_id']) && $request['flash_sale_id']) {

				$result = $this->updateFlashSaleFormValues($request);

				if($result){

					return Response::json(array('success'=>1, 'message'=>'Coupon updated successfully!'), 200);	
				}else{

					return Response::json(array('success'=>1, 'message'=>'Coupon not updated successfully!'), 200);
				}

			}else{

				$result = $this->saveFlashSaleFormValues($request);

				if($result){

					return Response::json(array('success'=>1, 'message'=>'Coupon added successfully, your coupon code is '.$result['coupon_code']), 200);	
				}else{

					return Response::json(array('success'=>1, 'message'=>'Coupon not added successfully!'), 200);
				}
			}			
		}
    }

    public function updateFlashSaleFormValues($input){

    	$flashSalesObj = \App\FlashSales::where('id','=',$input['flash_sale_id'])->first();
    	$flashSalesObj->coupon_name 	= $input['coupon_name'];
    	//$flashSalesObj->coupon_code 	= $this->generateUniqueCoupon();
    	$flashSalesObj->minimum_value 	= $input['minimum_value'];
    	$flashSalesObj->discount_type 	= $input['discount_type'];
    	$flashSalesObj->discount_amount = $input['discount_amount'];
    	$flashSalesObj->city	 		= $input['city'];
    	$flashSalesObj->country 		= $input['country'];
    	$flashSalesObj->from_date 		= date('Y-m-d',strtotime($input['from_date'])).' '.$input['from_time'];
    	$flashSalesObj->to_date 		= date('Y-m-d',strtotime($input['to_date'])).' '.$input['to_time'];
    	$flashSalesObj->from_time 		= $input['from_time'];
    	$flashSalesObj->to_time 		= $input['to_time'];
    	$flashSalesObj->created_at 		= date('Y-m-d h:i:s');
    	$flashSalesObj->updated_at 		= date('Y-m-d h:i:s');
    	$flashSalesObj->save();

    	return $flashSalesObj->id;
    }

    public function saveFlashSaleFormValues($input){

        $discount_amount = '';
        if($input['discount_type']=='flat'){

            $discount_amount = $input['discount_flat_amount'];

        }else{

            $discount_amount = $input['discount_perc_amount'];
        }

    	$flashSalesObj = new FlashSales;
    	$flashSalesObj->coupon_name 	= $input['coupon_name'];
    	$flashSalesObj->coupon_code 	= $this->generateUniqueCoupon();
    	$flashSalesObj->minimum_value 	= $input['minimum_value'];
    	$flashSalesObj->discount_type 	= $input['discount_type'];
    	$flashSalesObj->discount_amount = $discount_amount;
    	$flashSalesObj->city	 		= $input['city'];
    	$flashSalesObj->country 		= $input['country'];
    	$flashSalesObj->from_date 		= date('Y-m-d',strtotime($input['from_date'])).' '.$input['from_time'];
    	$flashSalesObj->to_date 		= date('Y-m-d',strtotime($input['to_date'])).' '.$input['to_time'];
    	$flashSalesObj->from_time 		= $input['from_time'];
    	$flashSalesObj->to_time 		= $input['to_time'];
    	$flashSalesObj->created_at 		= date('Y-m-d h:i:s');
    	$flashSalesObj->updated_at 		= date('Y-m-d h:i:s');
    	$flashSalesObj->save();

    	return $flashSalesObj;
    }

    public function getDisplayFlashSalesJsonList(Request $request){

    	$data = $request->all();

        //echo "<pre>"; print_r($data); exit;
        if (isset($data['draw'])) {

            $columnArray
                = array(                                         
                    'id', 
                    'minimum_value',
                    'discount_amount',
                    'coupon_code',
                    'country',
                    'discount_type',
                    'start_date',
                    'end_date'                                 
                 );

            try {    
                DB::enableQueryLog();
                
                /**
                 * Database query object selection
                 */
                $query = DB::table('flash_sales');

                /**
                 * field selection
                 */
                $query->select(
                    'id',
                    DB::raw('CONCAT("€", minimum_value) as minimum_value'),
                    'discount_amount',
                    'coupon_code',
                    'country',
                    'discount_type',
                    DB::raw('DATE_FORMAT(from_date, "%d-%m-%Y") as start_date'),
                    DB::raw('DATE_FORMAT(to_date, "%d-%m-%Y") as end_date')

                ); 

                       

                $flashSalesCount = count($query->get());
                /**
                 * Order by
                 */
                //echo "<pre>"; print_r($query->toSql()); exit;
                
                if (isset($data['order'])) {
                    $query->orderBy(
                        $columnArray[$data['order'][0]['column']],
                        $data['order'][0]['dir']
                    );
                }
                /**
                 * Apply limit
                 */
                if ($data['length'] != -1) {
                    $query->skip($data['start'])->take($data['length']);
                }
                  
                //echo "<pre>"; print_r($query->toSql()); exit;

                /**
                 * Get
                 */
                $flashSales = $query->get();
            } catch(\Exception $e) {//echo "<pre>"; print_r($query->toSql()); exit;
                $flashSales = [];
                $flashSalesCount = 0;
            }    

            $response['draw'] = $data['draw'];
            $response['recordsTotal'] = $flashSalesCount;
            $response['recordsFiltered'] = $flashSalesCount;

            $response['data'] = $flashSales;

            return response()->json($response);
        }
    }

    public function getDeleteFlashSale(Request $request){

        $id = $request['id'];

    	$result = DB::table('flash_sales')->where('id', $id)->delete();

    	if($result){

    		$response = array('success'=>1, 'message'=>'Flash Sale details deleted successfully!');

    		return response()->json($response);
    	}else{

    		$response = array('success'=>0, 'message'=>'Flash Sale details not deleted, try again!');

    		return response()->json($response);
    	}
    }

    public function getPropertyCountries(){

    	$result = DB::table('property_details')
    				->select('country')
    				->where('verified', 'yes')
    				->where('status', 'active')
    				->groupBy('country')
    				->orderBy('country', 'asc')
    				->get();

    	if($result){

    		$response = array('success'=>1, 'message'=>'Countries found', 'data'=>$result);

    		return response()->json($response);
    	}else{

    		$response = array('success'=>0, 'message'=>'No countries found');

    		return response()->json($response);
    	}		
    }
}
