<?php

namespace App;

use Illuminate\Database\Eloquent\Model;

use App\Invoices;

use Response;

use Mail;

use DB;

class Invoices extends Model
{
    protected $table = 'invoices';

    public static function getUpdateOwnerRenewalData($uid, $id, $payment_type, $currency_name, $currency_symbol, $payable_amount){

    	 
        $prev_data          = DB::table('invoices as in')
                                ->select(
                                	'in.renewal_date', 
                                	'in.expiry_date', 
                                	'u.status',
                                	'u.email'
                                )
                                ->leftJoin('users as u', 'u.id', '=', 'in.user_id')
                                ->where('in.id', $id)
                                ->first();
        
        $exp_date = date('Y-m-d', strtotime($prev_data['expiry_date']));
        $chk_date = date('Y-m-d');   
        if($chk_date > $exp_date){
                
            $renewal_date   = $chk_date;

        }else{
            
            $renewal_date   = $prev_data['renewal_date'];
        }                       
        
        $chk_expdate 		= date('Y-m-d', strtotime("+12 months $renewal_date"));
        $expiry_date        = date('Y-m-d', strtotime("-1 day $chk_expdate"));

        $user               = DB::table('users')
        		              ->where('id', $uid)
        		              ->update(array(
                    			'expiry_date'  =>$expiry_date,
                    			'status'	   =>'active'
                    		  ));
        $data               = DB::table('invoices')
        		              ->where('id', $id)
        		              ->update(array( 
        		              	'updated_at'                => date('Y-m-d'),                   			
                    			'status'	                =>'paid',
                    			'user_id'	                => $uid,
                                'payment_type'              => $payment_type,
                                'selected_currency_name'    => $currency_name,
                                'selected_currency_symbol'  => $currency_symbol,
                                'paid_amount'               => $payable_amount,	
                    		  ));

        $updated_user_data  = Invoices::getRenewalUpdatedStatus($id);

        $chk_nxt_expdate    = date('Y-m-d', strtotime("+12 months $chk_expdate"));
        $nxt_exp_date       = date('Y-m-d', strtotime("-1 day $chk_nxt_expdate"));
        
        $nxt_renewal_data   = DB::table('invoices')
                                ->insertGetId(array(
                                'renewal_date'=>$chk_expdate,
                                'expiry_date' =>$nxt_exp_date,
                                'price'       =>'299',
                                'status'      =>'pending',
                                'user_id'     =>$uid    
                              )); 
        $email = Invoices::sendInvoidSuccessMail($uid);
        if($data){

        	

            return Response::json(array('success'=>1, 'message'=>'Account renewal success', 'user_details'=>$updated_user_data), 200);
        }else{

            return Response::json(array('success'=>0, 'message'=>'Account renewal not success'), 400);
        }
    }

    public static function sendInvoidSuccessMail($uid){

    	$owner_details 	= Invoices::getInvoiceOwnerDetailsById($uid);

    	
    	$x = array_reverse($owner_details);
    	$paid_details 		= $x[1];
    	
    	$next_pay_details 	= end($owner_details);
    	
    	$payment_date 		= date('d-m-Y', strtotime($paid_details['updated_at']));
    	$owner_name 		= $paid_details['name'];
    	$email 				= $paid_details['email'];
    	$phone 				= $paid_details['phone'];
        $payment_type       = $paid_details['payment_type'];
        $paid_amount        = $paid_details['paid_amount'];
        $currency_name      = $paid_details['selected_currency_name'];
        $currency_symbol    = $paid_details['selected_currency_symbol'];
    	//echo "<pre>";
    	//print_r($paid_details);
    	//print_r($next_pay_details);    	
    	$msg = 'You have paid your invoice of Direct Owners successfully, please follow the below details of the payment.';
    	//echo $payment_date.'__'.$email.'__'.$msg;
    	//die();
    	$mail 			= Mail::send('emails.owner-invoice', [
    						'paid_details'		        => $paid_details,
    						'next_pay_details'	        => $next_pay_details,
    						'paid_date'   		        => $payment_date,
    						'owner_name'		        => $owner_name,
    						'email'				        => $email,
    						'phone'    			        => $phone,
                            'payment_type'              => $payment_type,
                            'selected_currency_name'    => $currency_name,
                            'selected_currency_symbol'  => $currency_symbol,
                            'paid_amount'               => $paid_amount			    						
    						], function ($m) use ($email) {

                                $m->from('info@direct-owners.com', 'Direct Owners');

                                $m->to($email)->subject('Invoice status mail');
                         });

    	$mail 			= Mail::send('emails.super-admin-invoice', [
    						'paid_details'		=>$paid_details,
    						'next_pay_details'	=>$next_pay_details,
    						'paid_date'   		=>$payment_date,
    						'owner_name'		=>$owner_name,
    						'email'				=>$email,
    						'phone'    			=>$phone,
                            'payment_type'              => $payment_type,
                            'selected_currency_name'    => $currency_name,
                            'selected_currency_symbol'  => $currency_symbol,
                            'paid_amount'               => $paid_amount 
    						], function ($m) use ($email) {

                                $m->from('info@direct-owners.com', 'Direct Owners');

                                $m->to('admin@direct-owners.com')->subject('Invoice status mail');
                         });

    	return $mail;
    }

    public static function getInvoiceOwnerDetailsById($uid){

		$data  = DB::table('invoices as in')
                    ->select(
                    	'in.*',
                    	DB::raw('CONCAT(u.first_name, " ", u.surname) AS name'),
                    	'u.email',
                    	'u.phone',
                    	DB::raw('in.price AS price'),
                    	'u.email',                    	
                    	DB::raw('DATE_FORMAT(u.created_datetime, "%d-%m-%Y") as active_since'),
                    	DB::raw('DATE_FORMAT(in.renewal_date, "%d-%m-%Y") as irenewal_date'),
                    	DB::raw('DATE_FORMAT(in.expiry_date, "%d-%m-%Y") as iexpiry_date'),
                    	(DB::raw('(SELECT count(property_id) FROM property_details as pd WHERE pd.user_id="'.$uid.'") no_of_properties')),
                    	(DB::raw('(SELECT count(id) FROM invoices WHERE user_id="'.$uid.'" and status="pending") pending_invoice'))

                    )	
                    ->leftJoin('users as u', 'u.id', '=', 'in.user_id')
                    ->where('in.user_id', $uid)
                    ->get();

        return $data;                
    }

    public static function getRenewalUpdatedStatus($id){

        $data          = DB::table('invoices as in')
                                ->select('in.renewal_date', 'in.expiry_date', 'u.status')
                                ->leftJoin('users as u', 'u.id', '=', 'in.user_id')
                                ->where('in.id', $id)
                                ->first();
        return $data;
    }

    public static function getOwnerRenewalStatus($uid){

        $data          = DB::table('users')
                                ->select('status')
                                ->where('id', $uid)
                                ->first();
        
        if($data){

                return Response::json(array('success'=>1, 'user_details'=>$data), 200);
        }else{

                return Response::json(array('success'=>0), 400);
        }                                
    }
}
