<?php

namespace App;

use Illuminate\Foundation\Auth\User as Authenticatable;

use Illuminate\Support\Facades\Storage;

use Illuminate\Support\Facades\Input;

use Twilio\Rest\Client;

use DB;

use Mail;

use Response;

use DateTime;

use Hash;

use App\PropertyDetails;
use Config;
use Log;
use Intervention\Image\Facades\Image as Image;
class User extends Authenticatable
{
    public function __construct(){
      
       $this->from_email             = Config::get('app.email_from_address');
       $this->_s3_path               = Config::get('filesystems.s3_path');

       //print_r($$this->_s3_path); die();
    }   

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'first_name','surname', 'email', 'password',
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];

    public static function signup($input) {     
            
            //print_r($input);die();
            $user_id = User::createNewUser($input);           
            
            // finding user's details
            $user_details = User::getUserDetailsWithId($user_id);
            
            $user = array($input['email']);
                $name = $input['first_name'].' '.$input['surname'];
                $mail =  Mail::send('emails.signup-email-verification', ['name'=>$name,'id'=>$user_id,'email' => $user], function ($m) use ($user) {

                                $m->from('info@direct-owners.com', 'Direct Owners');

                                $m->to($user)->subject('Complete the Registration Process - Direct-Owners');
                            });

            if($user_details){                   
                
                return Response::json(array('success'=>1, 'message'=>'Signup successful!', 'user_details'=>$user_details), 200);                
                
            }    
            else{

                return Response::json(array('success'=>0, 'message'=>'User not found!'), 404);
            }
        
    }

    public static function createNewUser($input){   

        $phonecode = '';

        $landlinecode = ''; 

        $landline = '';

        if(isset($input['phone'])){

            $phone = $input['phone']?$input['phone']:'';
        }

        if(isset($input['landline'])){

            $landline = $input['landline']?$input['landline']:'';
        }

        $img_name = strtolower($input['first_name'].'_'.$input['surname']);

        if(Input::hasfile('profile_pic')){

            $profile_pic= User::userProfileImage($img_name);

        }else{
            $profile_pic = '';
        }      
        
        $self_introduction  = isset($input['self_introduction'])?$input['self_introduction']:'';
        $address            = isset($input['address'])?$input['address']:'';
        $nickname           = isset($input['nickname'])?$input['nickname']:'';
        $language           = isset($input['language'])?$input['language']:'';
        $skype_url          = isset($input['skype_url'])?$input['skype_url']:'';
        $facebook_url       = isset($input['facebook_url'])?$input['facebook_url']:'';
        $twitter_url        = isset($input['twitter_url'])?$input['twitter_url']:'';
        $linkdin_url        = isset($input['linkdin_url'])?$input['linkdin_url']:'';
        $pinterest_url      = isset($input['pinterest_url'])?$input['pinterest_url']:'';
        $snapchat_url       = isset($input['snapchat_url'])?$input['snapchat_url']:'';
        

        $data = DB::table('users')
                    ->insertGetId(array(
                        'token' => str_random(40),
                        'title' => $input['title'],
                        'first_name' => $input['first_name'],
                        'surname' => $input['surname'],
                        'email' => $input['email'],
                        'password' => Hash::make($input['password']),
                        'phone' => $phone,
                        'profile_pic'=> $profile_pic,
                        'landline' =>$landline,
                        'self_introduction' =>$self_introduction,
                        'address' =>$address,
                        'nickname' =>$nickname,
                        'language' =>$language,
                        'skype_url' =>$skype_url,
                        'facebook_url' =>$facebook_url,
                        'twitter_url' =>$twitter_url,
                        'twitter_url' =>$twitter_url,
                        'linkdin_url' =>$linkdin_url,
                        'pinterest_url' =>$pinterest_url,
                        'snapchat_url' =>$snapchat_url,
                        'created_datetime' => new DateTime
                    ));

        return $data;
    }    

    public static function login($input){

        $data = User::getUserDetailsWithEmail($input['email']);
            
            if ($data) {
                if(Hash::check($input['password'], $data['password'])){
                    
                    if($data['status']=='active'){

                        $x = User::updateUserToken($data['id']);

                        //$renewal_check = User::getCheckUserRenewalStatus($data['id']);

                        // finding user's details
                        $user_details = User::getUserDetailsWithIdForLogin($data['id']);



                        if($user_details)
                            return $user_details;
                        else
                           return 'no';
                    }else{

                        return Response::json(array('success'=>0, 'message'=>'You cannot login into this website'), 400);
                    }
                    
                }
                else
                    return Response::json(array('success'=>0, 'message'=>'Password is incorrect!'), 400);
            }
            else
                return Response::json(array('success'=>0, 'message'=>'User not found!'), 404);
    }

    public static function getCheckUserRenewalStatus($uid){

        $data = DB::table('users as u')
                ->select('u.expiry_date', 'u.status', 'in.status as pay_status', 'in.expiry_date as pay_exp_date')
                ->leftJoin('invoices as in', 'in.user_id', '=', 'u.id')
                ->where('u.id', $uid)
                ->orderBy('in.id', 'desc')
                ->first();

        $exp_date = date('Y-m-d', strtotime($data['expiry_date']));
        $status   = $data['pay_status'];
        $chk_date = date('Y-m-d');        
        $datediff = strtotime($exp_date) - strtotime($chk_date);
        $daysLeft = $datediff/(60 * 60 * 24);   
        //echo $daysLeft;die();
        if($exp_date >= $chk_date && $status=='pending'){           
              
            $renewalAccMail = User::userAccountRenewalNotification($uid, $daysLeft, $exp_date);                 
        }else{

            $renewalAccMail = User::userAccountRenewalNotification($uid, $daysLeft, $exp_date);

            $update = DB::table('users')
                      ->where('id', $uid)
                      ->update(array(
                        'status'=>'inactive'
                      ));              
              
            return $update;
        }     

    }

    public static function userAccountRenewalNotification($uid, $nofdays, $exp){
        
        $date = date('d-m-Y', strtotime($exp));
        
        switch ($nofdays) {
            case '15':
                    $msg  = 'Your account is going to be expire with in 15 days i.e('.$date.'), Please renew your account to avoid any inconvenience.'; 
                    $mail = User::sendRenewalAccountMail($uid, $msg);                           
                break;

            case '10':
                    $msg = 'Your account is going to be expire with in 10 days i.e('.$date.'), Please renew your account to avoid any inconvenience.';
                    $mail = User::sendRenewalAccountMail($uid, $msg);
                break;

            case '5' :
                    $msg = 'Your account is going to be expire with in 5 days i.e('.$date.'), Please renew your account to avoid any inconvenience.';
                    $mail = User::sendRenewalAccountMail($uid, $msg);
                break;

            case '1' :
                    $msg = 'Your account is going to be expire tomorrow i.e('.$date.'), Please renew your account to avoid any inconvenience.';
                    $mail = User::sendRenewalAccountMail($uid, $msg);
                break;                

            case '-1' :
                    $msg = 'Your account was expired on ('.$date.'), please renew your account to avoid any inconvenience.';
                    $mail = User::sendRenewalAccountMail($uid, $msg);
                break;              
            
            default:
                # code...
                break;
        }            
    }

    public static function sendRenewalAccountMail($uid, $msg){

        $userData   = DB::table('users as u')
                        ->select(DB::raw('CONCAT(u.first_name, " ", u.surname) AS name'),'u.email')
                        ->where('u.id', $uid)                    
                        ->first();
        $name       = $userData['name'];                
        $email      = $userData['email'];                
        $mail       =  Mail::send('emails.account-renewal-alert', 
                               ['name'   => $name,
                                'msg'    => $msg,
                                'email'  => $email
                               ], function ($m) use ($email) {

                               $m->from('info@direct-owners.com', 'Direct Owners');

                               $m->to($email)->subject('Account renewal alert from Direct Owners');
                        });
        return $mail;
    }

    public static function getUserDetailsWithEmail($email){

        $data = DB::table('users')
                    ->select('id', 'first_name','surname', 'email', 'password', 'status')
                    ->where('email', $email)
                    ->first();

        return $data;
    }

    public static function getUserDetailsWithIdForLogin($user_id){       

        $data = DB::table('users as u')
                    ->select(DB::raw('CONCAT(u.first_name, " ", u.surname) AS name'), 'u.password as auth_token', 'u.id', 'u.profile_pic','u.email', 'u.email_verification', 'u.phone_verification', 'u.status', 'u.payment_method_token', 'u.basic_currency', 'u.tmt_api_token', 'u.paypal_email')
                    ->where('u.id', $user_id)
                    ->where('u.email_verification', 'yes')
                    ->where('u.phone_verification', 'yes')
                    ->first();


        return $data;
    }

    /*public static function getUserDetailsWithIdForSignUp($user_id){

        $data = DB::table('users as u')
                    ->select(DB::raw('CONCAT(u.first_name, " ", u.surname) AS name'),'token', 'u.id', 'u.profile_pic')
                    ->where('u.id', $user_id)
                    ->where('u.email_verification', 'yes')
                    ->where('u.phone_verification', 'yes')                    
                    ->first();        
        return $data;

    }*/
    public static function getUserDetailsWithId($user_id){

        $data = DB::table('users as u')
                    ->select(DB::raw('CONCAT(u.first_name, " ", u.surname) AS name'),'token', 'u.id', 'u.profile_pic','u.email', 'u.email_verification', 'u.phone_verification','u.password as auth_token', 'u.status', 'u.payment_method_token','u.basic_currency', 'u.tmt_api_token', 'u.paypal_email')
                    ->where('u.id', $user_id)                    
                    ->first();        
        return $data;
    }


    public static function updateUserToken($user_id) {

        $token  = str_random(40);
        $data   = DB::table('users as u')
                    ->where('u.id', $user_id)
                    ->update(array(
                        'token' => $token,
                  ));
                    
        return $token;
    }

    public static function updateUserEmailVerificationStatus($s, $id){

        $data   = DB::table('users as u')
                    ->select('u.*')
                    ->where('u.id', $id)
                    ->update(array(
                        'email_verification' => $s,
                  )); 
        if($data){            
            $user_details = DB::table('users as u')
                    ->select(DB::raw('CONCAT(u.first_name, " ", u.surname) AS name'),'token', 'u.id', 'u.profile_pic','u.email', 'u.email_verification','u.phone', 'u.phone_verification','u.password as auth_token', 'u.payment_method_token','u.basic_currency', 'u.tmt_api_token', 'u.paypal_email')
                    ->where('u.id', $id)                    
                    ->first(); 
            return Response::json(array('success'=>1, 'user_details'=>$user_details));
            //return $user_details;
        }else{
            return Response::json(array('success'=>0, 'user_details'=>'Not Updated'));
        }

    }

    public static function getUpdateUserDetails($request){       

        $user_details = User::getUpdateUserData($request);
       
        if($user_details){

                return Response::json(array('success'=>1, 'message'=>'User details updated successfully !', 'user_details'=>$user_details), 200);
        }else{

                return Response::json(array('success'=>0, 'message'=>'User details not updated!, Please try again'), 400);
        }            

    }

    public static function getUpdateUserData($request){
        
        $user    = User::getExistingUserDetails($request['user_id']);

        $user_id            = $request['user_id']?$request['user_id']:'0';
        $title              = isset($request['title'])?$request['title']:$user['title'];
        $first_name         = isset($request['first_name'])?$request['first_name']:$user['first_name'];
        $surname            = isset($request['surname'])?$request['surname']:$user['surname'];
        $email              = isset($request['email'])?$request['email']:$user['email'];
        $phone              = isset($request['phone'])?$request['phone']:$user['phone'];
        $landline           = isset($request['landline'])?$request['landline']:$user['landline'];
        $self_introduction  = isset($request['self_introduction'])?$request['self_introduction']:$user['self_introduction'];
        $address            = isset($request['address'])?$request['address']:$user['address'];
        $nickname           = isset($request['nickname'])?$request['nickname']:$user['nickname'];
        $language           = isset($request['language'])?$request['language']:$user['language'];
        $skype_url          = isset($request['skype_url'])?$request['skype_url']:$user['skype_url'];
        $facebook_url       = isset($request['facebook_url'])?$request['facebook_url']:$user['facebook_url'];
        $twitter_url        = isset($request['twitter_url'])?$request['twitter_url']:$user['twitter_url'];
        $pinterest_url      = isset($request['pinterest_url'])?$request['pinterest_url']:$user['pinterest_url'];
        $snapchat_url       = isset($request['snapchat_url'])?$request['snapchat_url']:$user['snapchat_url'];
        $linkdin_url        = isset($request['linkdin_url'])?$request['linkdin_url']:$user['linkdin_url'];
        //$paypal_email       = isset($request['paypal_email'])?$request['paypal_email']:$user['paypal_email'];

        $img_name = strtolower($first_name.'_'.$surname);

        
        if(isset($request['profile_pic'])){ 
            $del_path           = 'uploads/profile_pics/'.$user['profile_pic'];
            //Log::info(print_r($del_path.' del_path', true));
            $del_from_storage   =  Storage::disk('s3')->delete($del_path
            );
            //Log::info(print_r($del_from_storage.' del_from_storage', true));
            $profile_pic= User::userProfileImage($img_name);
        }else{
            
            $profile_pic = $user['profile_pic'];
        }

        $data   = DB::table('users as u')
                    ->where('u.id', $user_id)
                    ->update(array(
                        'title'             => $title,
                        'first_name'        => $first_name,
                        'surname'           => $surname,
                        'email'             => $email,
                        //'paypal_email'      => $paypal_email,
                        'phone'             => $phone,
                        'landline'          => $landline,
                        'self_introduction' => $self_introduction,
                        'address'           => $address,
                        'profile_pic'       => $profile_pic,
                        'nickname'          => $nickname,
                        'language'          => $language,
                        'skype_url'         => $skype_url,
                        'facebook_url'      => $facebook_url,
                        'twitter_url'       => $twitter_url,
                        'linkdin_url'       => $linkdin_url,
                        'pinterest_url'     => $pinterest_url,
                        'snapchat_url'      => $snapchat_url,
                ));

        if($data){

                $name = $first_name.' '.$surname;
                
                $mail =  Mail::send('emails.profile-update', ['name'=>$name,'id'=>$user_id,'email' => $email], function ($m) use ($email) {

                                $m->from('info@direct-owners.com', 'Direct Owners');

                                $m->to($email)->subject('Owner profile update from Direct Owners');
                         });
        }                    
                   
        return $data;            

    }

    public static function getExistingUserDetails($id){

        $data = DB::table('users as u')
                ->select('u.*')
                ->where('u.id', $id)
                ->first();
        return $data;        

    }

    public static function getDeleteUserDetails($id){

        $id = $id?$id:'0';
        $property_id = User::getPropertyIdByOwnerId($id);        

        $update = array('status'=>'inactive');
        $data = DB::table('users')->where('id', $id)->update($update);

        
        //$property_enquiry    = DB::table('property_enquiry')->where('owner_id', $id)->delete();

        if(count($property_id)){
            $inactive_owner_props = DB::table('property_details')->where('user_id', $id)->update($update);
        }        

        if($data){

                return Response::json(array('success'=>1, 'user_details'=>$data), 200);
        }else{

                return Response::json(array('success'=>0, 'message'=>'No user found, Please try again'), 400);
        } 
    }

    public static function getPropertyIdByOwnerId($id){

        $result = array();
        $data = DB::table('property_details')
                ->select('property_id')
                ->where('user_id', $id)
                ->get();
        foreach($data as $k => $v) {           
           array_push($result, $v['property_id']); 
        }   
        return $result;        
    }    

    public static function getAllUsersList(){

        $data = DB::table('users as u')
                ->get();
        return Response::json($data);        
    }

    public static function getUserDetailsById($id){

        $id = $id?$id:'0';

        $data = DB::table('users as u')
                ->select('u.*')
                ->where('u.id', $id)
                ->first();

        if($data){

            return $data;
        }else{

            return '';
        }  
    }

    public static function changeUserPassword($input){

        if(isset($input['old_password']) && isset($input['new_password'])){
            $user_id = isset($input['user_id'])?$input['user_id']:'';
            $oldPwd = User::getUserOldPwd($user_id);
            // now match old password, move forward if it matches
            if((Hash::check($input['old_password'], $oldPwd['password']))){

                //Set the new password
                $updatePass= User::updatePassword($user_id, $input['new_password']);

                if($updatePass)
                    return Response::json(array('success'=> 1,'msg'=>'Password changed successfully!'), 200);
                else
                    return Response::json(array('success'=> 0,'msg'=>'Could not change password!'), 200);

            }

            else
                return Response::json(array('success'=> 0,'msg'=>'Old password incorrect!!'), 200);
        }
        else
            return Response::json(array('success'=> 0,'msg'=>'Incomplete Parameters!'), 200);
    }

    public static function getUserOldPwd($id)
    {
        $data = DB::table('users as u')
                ->select('u.password')
                ->where('u.id', $id)
                ->first();
        return $data;       
    }

    public static function updatePassword($userId, $newPassword){

        // update password
        $update= DB::table('users as u')
                    ->where('u.id', $userId)
                    ->update(array(
                                'password' => Hash::make($newPassword)
                                ));

        return $update ? true : false;
    }

    public static function userProfileImage($img_name){

            $input = Input::all();

            $profile_pic= isset($input['profile_pic']) ? $input['profile_pic']:'';

            $file = Input::file('profile_pic');

            if(isset($file)){

                if(Input::file('profile_pic')->isValid())
                {
                    //store file input in a varaible
                    $file = Input::file('profile_pic');
                    //Log::info(print_r(file_get_contents($file), true));
                    //get extension of file
                    $extension =$file->getClientOriginalExtension();

                    //define directory to store images
                    $directory  = 'uploads/profile_pics/';
                    $local_directory = public_path().'/uploads/profile_pics/';
                    if (!file_exists($local_directory)) {
                        mkdir($local_directory, 0777, true);
                    }


                   $filename        = "user_".time()."_".$img_name.".{$extension}";
                   $local_img       = Input::file('profile_pic')->move($local_directory, $filename);

                   $image           = Image::make($local_img);
                   $resize_image    = $image->fit(640,427)->stream();
                    //Move the uploaded file to temp directory
                   $upload_success  = Storage::disk('s3')->put($directory.'/'.$filename, $resize_image->__toString(), 'public');
                   
                   if($upload_success){
                    unlink($local_directory.'/'.$filename);
                   }
                    //$upload_success = Input::file('profile_pic')->move($directory, $filename);
                   
                    //dd($upload_success);
                    return $upload_success ? $filename : $profile_pic;
                }
            }

            return $profile_pic;
    }
    
    public static function sendUserOTP($mobile, $uid){
        $user = DB::table('users as u')
                ->where('u.id', $uid)
                ->where('u.phone','like', '%'.$mobile.'%')
                ->first(); 

        if($user){
             $otp= rand(100000, 999999);

             $accountSid    = "AC8ec841f4335bf65f8d87a13a84c74290";
             $authToken     = "b8d83251166793cd165513f1d3fef90e";

             $message       = "Direct Owners - Your verification code is ".$otp;                
             $client        = new  Client($accountSid, $authToken);
             $user_num      = $mobile;
             try {
                    $num = $client->messages->create(
                        $user_num,
                        array(
                            "body" => $message,
                            "from" => '+13476479122'                            
                        )
                    );
                    
            } catch (TwilioException $e) {
                    Log::error(
                        'Could not send SMS notification.' .
                        ' Twilio replied with: ' . $e
                    );
            }


             $update= DB::table('users as u')
                    ->where('u.id', $uid)
                    ->update(array(
                                'mobile_otp' => $otp
                                ));
            return Response::json(array('success'=> 1,'msg'=>'OTP sent successfully!'), 200);         

        }else{

            if($mobile){

                 $otp= rand(100000, 999999);

                 $accountSid    = "AC8ec841f4335bf65f8d87a13a84c74290";
                 $authToken     = "b8d83251166793cd165513f1d3fef90e";

                 $message = "Your verification code is ".$otp;                
                 $client = new  Client($accountSid, $authToken);
                 $user_num = $mobile;
                 try {
                        $num = $client->messages->create(
                            $user_num,
                            array(
                                "body" => $message,
                                "from" => '+13476479122'                            
                            )
                        );
                        
                } catch (TwilioException $e) {
                        Log::error(
                            'Could not send SMS notification.' .
                            ' Twilio replied with: ' . $e
                        );
                }


                 $update= DB::table('users as u')
                        ->where('u.id', $uid)
                        ->update(array(
                                    'phone' =>$mobile,
                                    'mobile_otp' => $otp
                                    ));
                return Response::json(array('success'=> 1,'msg'=>'OTP sent successfully!'), 200);
                }
            //return Response::json(array('success'=> 0,'msg'=>'Not registered mobile number'), 400);
        }

    }

    public static function checkUserOTP($otp, $uid){

            $user           = DB::table('users as u')
                                ->select(DB::raw('CONCAT(u.first_name, " ", u.surname) AS name'),'token', 'u.id', 'u.profile_pic','u.email', 'u.email_verification', 'u.phone_verification','u.password as auth_token','u.created_datetime', 'u.payment_method_token','u.basic_currency', 'u.tmt_api_token', 'u.paypal_email')
                                ->where('u.id', $uid)
                                ->where('u.mobile_otp', $otp)
                                ->first();
        if($user){

            $date           	= $user['created_datetime']; 
            $subscription_year  = date('Y-m-d', strtotime("+12 months $date"));
            $expiry         	= date('Y-m-d', strtotime("-1 day $subscription_year"));   
            $update         	= DB::table('users as u')
	                                ->where('u.id', $uid)
	                                ->update(array(
	                                    'phone_verification' => 'yes',
	                                    'expiry_date' =>$expiry,
	                                    'status' => 'active'
	                                ));

            $update_renewal = User::getUpdateUserRenewalDetails($uid);

            $user_details   = User::getUserDetailsWithId($uid);

            $mail           = Mail::send('emails.welcome', ['user_details'=>$user_details],                function ($m) use ($user_details) {

                                $m->from('info@direct-owners.com', 'Direct Owners');

                                $m->to($user_details['email'])->subject('Welcome Your Registration is Complete – Direct-Owners');
                               });

            return Response::json(array('success'=> 1,'msg'=>'Phone verification done successfully!', 'user'=>$user_details), 200); 

        }else{

            return Response::json(array('success'=> 0,'msg'=>'The code you entered was incorrect. Please re-enter the correct code or request a new one'), 400); 
        }        

    }

    public static function getUpdateUserRenewalDetails($id){

        $data = DB::table('users as u')
                ->select('u.created_datetime')
                ->where('u.id', $id)
                ->first();
        if($data){
            $date 			= $data['created_datetime'];
            $chk_date 		= date('Y-m-d', strtotime("+12 months $date"));
            $renewal_date   = $data['created_datetime'];
            $expiry_date 	= date('Y-m-d', strtotime("-1 day $chk_date"));
            $nxt_renwl_date = date('Y-m-d', strtotime("+1 day $expiry_date"));
            $nxt_renwl_year = date('Y-m-d', strtotime("+12 months $nxt_renwl_date"));
            $nxt_exp_date	= date('Y-m-d', strtotime("-1 day $nxt_renwl_year")); 
            $data_to_insert = array(
                array(  'renewal_date' => $renewal_date,
                        'expiry_date'  => $expiry_date,
                        'price'        => '0',
                        'status'       => 'paid',
                        'user_id'      => $id),
                array(  'renewal_date' => $nxt_renwl_date,
                        'expiry_date'  => $nxt_exp_date,
                        'price'        => '299',
                        'status'       => 'pending',
                        'user_id'      => $id)
            );
            $renewal = DB::table('invoices')
                       ->insert($data_to_insert);

            return $renewal;
        }        
    }
    
}
